@@ -1,31 +1,17 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
- 
-                         dialogdatasetselect.cpp  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                               *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
-
- 
+/**
+ * @file dialogdatasetselect.cpp
+ * @brief Implements the DialogDatasetSelect class for selecting datasets in SocNetV.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
 #include "dialogdatasetselect.h"
 
@@ -39,7 +25,7 @@ DialogDataSetSelect::DialogDataSetSelect (QWidget *parent) :
 {
     ui->setupUi(this);
 
-    (ui->buttonBox) -> button (QDialogButtonBox::Ok) -> setDefault(true);
+    (ui->buttonBox)->button (QDialogButtonBox::Ok)->setDefault(true);
 
     datasets_list
             << "Krackhardt: High-tech managers (multirelational), 24 actors"
@@ -59,6 +45,7 @@ DialogDataSetSelect::DialogDataSetSelect (QWidget *parent) :
             << "Knoke: Bureaucracies Information & Money Exchange Network, 10 actors, 2 relationships"
             << "Stephenson and Zelen (1989): Network of 40 AIDS patients (sex relationship)"
             << "Stephenson and Zelen (1989): Information Centrality test dataset, 5 actors"
+            << "Dunbar and Dunbar (1975): Network of Gelada baboon colony (H22a), 12 actors"
             << "Wasserman and Faust: star, circle and line graphs of 7 actors (multirelational)"
             << "Wasserman and Faust: Countries Trade (basic manufactured goods), 24 actors"
             << "Borgatti (1992): Campnet dataset, 18 actors"
@@ -83,20 +70,21 @@ DialogDataSetSelect::DialogDataSetSelect (QWidget *parent) :
             << "Knoke_Bureaucracies_Network.pajek"
             << "Stephenson&Zelen_40_AIDS_patients_sex_contact.paj"
             << "Stephenson&Zelen_5actors_6edges_IC_test_dataset.paj"
+            << "Stephenson&Zelen_Dunbar&Dunbar_Gelada_baboon_colony_H22a_IC.paj"
             << "Wasserman_Faust_7actors_star_circle_line_graphs.paj"
             << "Wasserman_Faust_Countries_Trade_Data_Basic_Manufactured_Goods.pajek"
             << "Campnet.paj"
             << "Petersen_Graph.paj"
             << "Herschel_Graph.paj";
 
-    (ui->selectBox) -> insertItems( 1, datasets_list );
+    (ui->selectBox)->insertItems( 1, datasets_list );
 }
 
 
 
 void DialogDataSetSelect::getUserChoices(){
     qDebug()<< "DialogDataSetSelect: gathering Data!...";
-    int index = (ui->selectBox) -> currentIndex();
+    int index = (ui->selectBox)->currentIndex();
     QString dataset_name = datasets_filenames[index];
     qDebug()<< "DialogDataSetSelect: user selected: " << dataset_name;
 	emit userChoices( dataset_name );
