@@ -1,29 +1,17 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
-
-                         dialogexportimage.cpp  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
+/**
+ * @file dialogexportimage.cpp
+ * @brief Implements the DialogExportImage class for exporting network visualizations as images in SocNetV.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
 #include "dialogexportimage.h"
 #include "ui_dialogexportimage.h"
@@ -53,7 +41,7 @@ DialogExportImage::DialogExportImage(QWidget *parent) :
     connect ( ui->fileDirSelectButton, &QToolButton::clicked,
              this, &DialogExportImage::getFilename);
 
-    connect ( ui->formatSelect, SIGNAL(currentIndexChanged (const QString &)),
+    connect ( ui->formatSelect, SIGNAL(currentTextChanged (const QString &)),
           this, SLOT ( getFormat(const QString &)) );
 
     connect ( ui->buttonBox,SIGNAL(accepted()), this, SLOT(getUserChoices()) );
@@ -79,8 +67,8 @@ DialogExportImage::DialogExportImage(QWidget *parent) :
 
     // Set default button
     // OK button is disabled until user has selected a filename.
-    (ui->buttonBox) -> button (QDialogButtonBox::Cancel) -> setDefault(true);
-    (ui->buttonBox) -> button (QDialogButtonBox::Ok) -> setEnabled(false);
+    (ui->buttonBox)->button (QDialogButtonBox::Cancel)->setDefault(true);
+    (ui->buttonBox)->button (QDialogButtonBox::Ok)->setEnabled(false);
 
     // Set which widget will have focus
     ui->fileDirSelectButton->setFocus(Qt::OtherFocusReason);
@@ -128,7 +116,7 @@ void DialogExportImage::changeQualityRange(const int &min, const int &max, const
 
 
 /**
- * @brief Gets the filename of the Image
+ * @brief Opens a dialog to get the filename of the new image to export
  */
 void DialogExportImage::getFilename(){
 
@@ -151,18 +139,18 @@ void DialogExportImage::getFilename(){
         }
         ui->fileEdit->setText(m_fileName);
         ui->fileEdit->setGraphicsEffect(0);
-        (ui->buttonBox)->button (QDialogButtonBox::Ok) -> setEnabled(true);
-        (ui->buttonBox)->button (QDialogButtonBox::Ok) -> setDefault(true);
+        ui->fileDirSelectButton->setGraphicsEffect(0);
+        (ui->buttonBox)->button (QDialogButtonBox::Ok)->setEnabled(true);
+        (ui->buttonBox)->button (QDialogButtonBox::Ok)->setDefault(true);
     }
     else {
-        qDebug() << " empty or dir does not exist";
-        // TODO Error message on form.
+        qDebug() << "Empty filaname or dir does not exist";
         QGraphicsColorizeEffect *effect = new QGraphicsColorizeEffect;
         effect->setColor(QColor("red"));
         ui->fileEdit->setGraphicsEffect(effect);
         ui->fileDirSelectButton->setGraphicsEffect(effect);
-        (ui->buttonBox) -> button (QDialogButtonBox::Ok) -> setEnabled(false);
-        (ui->buttonBox) -> button (QDialogButtonBox::Cancel) -> setDefault(true);
+        (ui->buttonBox)->button (QDialogButtonBox::Ok)->setEnabled(false);
+        (ui->buttonBox)->button (QDialogButtonBox::Cancel)->setDefault(true);
 
     }
 
@@ -175,16 +163,14 @@ void DialogExportImage::getFilename(){
  */
 void DialogExportImage::getFormat(const QString &format){
     QString m_format = format.toLower();
-    qDebug() << m_format;
+    qDebug() << "format:" << m_format;
     QString m_fileName = ui->fileEdit->text();
-    qDebug() << m_fileName;
-    qDebug() << QFileInfo(m_fileName).suffix();
-    if (  QString::compare(
-                          QFileInfo(m_fileName).suffix() , m_format, Qt::CaseInsensitive
-                          )
-          ) {
+    qDebug() << "filename" << m_fileName;
+    qDebug() << "suffix" << QFileInfo(m_fileName).suffix();
+    if (  QString::compare(QFileInfo(m_fileName).suffix() , m_format, Qt::CaseInsensitive) != 0 ) {
+        // User filename suffix differs from selected format. Correct the filename suffix.
         m_fileName = QFileInfo(m_fileName).absolutePath() + QDir::separator() + QFileInfo(m_fileName).completeBaseName().append("."+m_format);
-        qDebug() << m_fileName;
+        qDebug() << "Corrected filename:" << m_fileName;
     }
 
     ui->fileEdit->setText(m_fileName);
