@@ -1,29 +1,17 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
-
-                         dialogexportpdf.cpp  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
+/**
+ * @file dialogexportpdf.cpp
+ * @brief Implements the DialogExportPDF class for exporting network visualizations as PDF files in SocNetV.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
 #include "dialogexportpdf.h"
 #include "graphicswidget.h"
@@ -65,15 +53,15 @@ DialogExportPDF::DialogExportPDF (QWidget *parent ) :
     connect (ui->fileDirSelectButton, &QToolButton::clicked,
              this, &DialogExportPDF::getFilename);
 
-    connect(ui->qualitySelect, SIGNAL ( currentIndexChanged (const QString &)),
+    connect(ui->qualitySelect, SIGNAL ( currentTextChanged (const QString &)),
           this, SLOT(getPrinterMode(const QString &)) );
 
     connect ( ui->buttonBox,SIGNAL(accepted()), this, SLOT(getUserChoices()) );
 
     // Set Cancel as default button
     // The OK button disabled until user selects a file.
-    (ui->buttonBox) -> button (QDialogButtonBox::Cancel) -> setDefault(true);
-    (ui->buttonBox) -> button (QDialogButtonBox::Ok) -> setEnabled(false);
+    (ui->buttonBox)->button (QDialogButtonBox::Cancel)->setDefault(true);
+    (ui->buttonBox)->button (QDialogButtonBox::Ok)->setEnabled(false);
 
     // Set which widget will have focus
     ui->fileDirSelectButton->setFocus(Qt::OtherFocusReason);
@@ -105,18 +93,18 @@ void DialogExportPDF::checkFilename(const QString &fileName){
         }
         ui->fileEdit->setText(m_fileName);
         ui->fileEdit->setGraphicsEffect(0);
-        (ui->buttonBox)->button (QDialogButtonBox::Ok) -> setEnabled(true);
-        (ui->buttonBox)->button (QDialogButtonBox::Ok) -> setDefault(true);
+        ui->fileDirSelectButton->setGraphicsEffect(0);
+        (ui->buttonBox)->button (QDialogButtonBox::Ok)->setEnabled(true);
+        (ui->buttonBox)->button (QDialogButtonBox::Ok)->setDefault(true);
     }
     else {
-        qDebug() << " empty or dir does not exist";
-        // TODO Error message on form.
+        qDebug() << "Empty filaname or dir does not exist";
         QGraphicsColorizeEffect *effect = new QGraphicsColorizeEffect;
         effect->setColor(QColor("red"));
         ui->fileEdit->setGraphicsEffect(effect);
         ui->fileDirSelectButton->setGraphicsEffect(effect);
-        (ui->buttonBox) -> button (QDialogButtonBox::Ok) -> setEnabled(false);
-        (ui->buttonBox) -> button (QDialogButtonBox::Cancel) -> setDefault(true);
+        (ui->buttonBox)->button (QDialogButtonBox::Ok)->setEnabled(false);
+        (ui->buttonBox)->button (QDialogButtonBox::Cancel)->setDefault(true);
 
     }
 
