@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 2.8
+ version: 3.2
  Written in Qt
 
                          dialogsettings.h  -  description
                              -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
+    copyright         : (C) 2005-2023 by Dimitris B. Kalamaras
     project site      : https://socnetv.org
 
  ***************************************************************************/
@@ -33,10 +33,8 @@
 
 
 
-
-
 namespace Ui {
-class DialogSettings;
+ class DialogSettings;
 }
 
 class DialogSettings : public QDialog
@@ -85,6 +83,8 @@ public slots:
     void getEdgeWeightNumbersVisibility(const bool &toggle);
     void getEdgeLabelsVisibility(const bool &toggle);
 
+    void getSaveZeroWeightEdges(const bool &toggle);
+
 signals:
     void setReportsDataDir (const QString &dir);
 
@@ -92,7 +92,7 @@ signals:
     void setReportsLabelLength(const int &length);
     void setReportsChartType(const int &type);
 
-    void setStyleSheetDefault(const bool &toggle);
+    void setCustomStylesheet(const bool &toggle);
 
     void setProgressDialog(bool);
     void setToolBar(bool);
@@ -104,8 +104,9 @@ signals:
 
     void setCanvasBgColor(const QColor);
     void setCanvasBgImage();
-    void setCanvasAntialiasing(bool);
-    void setCanvasAntialiasingAutoAdjust(bool );
+    void setCanvasOpenGL(const bool &);
+    void setCanvasAntialiasing(const bool &);
+    void setCanvasAntialiasingAutoAdjust(const bool &);
     void setCanvasSmoothPixmapTransform(bool);
     void setCanvasSavePainterState(bool);
     void setCanvasCacheBackground(bool);
@@ -133,6 +134,7 @@ signals:
     void setEdgeOffsetFromNode(const int&offset, const int &v1=0, const int &v2=0);
     void setEdgeWeightNumbersVisibility(const bool &toggle);
     void setEdgeLabelsVisibility(const bool &toggle);
+    void setSaveZeroWeightEdges(const bool &toggle);
     void saveSettings();
 private:
      QMap<QString, QString> &m_appSettings ;
