@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 2.8
+ version: 3.2
  Written in Qt
  
                          dialogwebcrawler.h  -  description
                              -------------------
-    copyright            : (C) 2005-2021 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2023 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
     website:             : http://dimitris.apeiro.gr
     project site         : https://socnetv.org
@@ -30,6 +30,7 @@
 #ifndef WEBCRAWLERDIALOG_H
 #define WEBCRAWLERDIALOG_H
 
+class QUrl;
 
 #include <QDialog>
 
@@ -47,7 +48,7 @@ public slots:
     void getUserChoices ();
     QStringList parseTextEditInput(const QString &html);
 signals:
-    void userChoices( const QString &seedUrl,
+    void userChoices( const QUrl &startUrl,
                       const QStringList &,
                       const QStringList &,
                       const QStringList &,
@@ -57,7 +58,7 @@ signals:
                       const bool &childLinks,
                       const bool &parentLinks,
                       const bool &selfLinks,
-                      const bool &extLinksIncluded,
+                      const bool &extLinksAllowed,
                       const bool &extLinksCrawl,
                       const bool &socialLinks,
                       const bool &delayedRequests
@@ -65,10 +66,11 @@ signals:
     void webCrawlerDialogError(QString);
 private:
     Ui::DialogWebCrawler ui;
-    QString seedUrl ;
+    QString seedUrlInputStr;
+    QUrl seedUrl ;
     int maxLinksPerPage, maxUrlsToCrawl;
     bool extLinks, intLinks;
-    bool extLinksIncluded;
+    bool extLinksAllowed;
     bool childLinks, parentLinks;
     bool socialLinks;
     QStringList linkClasses;
