@@ -1,29 +1,20 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
+/**
+ * @file graphicsedge.cpp
+ * @brief Implements the GraphicsEdge class, which visualizes edges in the network graph.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
-                        graphicsedge.cpp  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
 
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
+#include "graphicsedge.h"
 
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
@@ -34,7 +25,6 @@
 
 #include "global.h"
 #include "graphicswidget.h"
-#include "graphicsedge.h"
 #include "graphicsnode.h"
 #include "graphicsedgeweight.h"
 #include "graphicsedgelabel.h"
@@ -44,22 +34,22 @@ SOCNETV_USE_NAMESPACE
 
 
 GraphicsEdge::GraphicsEdge(GraphicsWidget *gw,
-             GraphicsNode *from,
-             GraphicsNode *to,
-             const qreal &weight,
-             const QString &label,
-             const QString &color,
-             const Qt::PenStyle &style,
-             const int &type,
-             const bool &drawArrows,
-             const bool &bezier,
-             const bool &weightNumbers, const bool &highlighting) : graphicsWidget(gw)
+                           GraphicsNode *from,
+                           GraphicsNode *to,
+                           const qreal &weight,
+                           const QString &label,
+                           const QString &color,
+                           const Qt::PenStyle &style,
+                           const int &type,
+                           const bool &drawArrows,
+                           const bool &bezier,
+                           const bool &weightNumbers, const bool &highlighting) : graphicsWidget(gw)
 {
 
     graphicsWidget->scene()->addItem(this);  //add edge to scene to be displayed
 
-    from->addOutLink( this );       // adds this new edge to sourceNode
-    to->addInLink( this );          // adds this new edge to targetNode
+    from->addOutEdge( this );       // adds this new edge to sourceNode
+    to->addInEdge( this );          // adds this new edge to targetNode
 
     source=from;                    // saves the source node
     target=to;                      // saves the target node
@@ -96,13 +86,13 @@ GraphicsEdge::GraphicsEdge(GraphicsWidget *gw,
 
     m_drawWeightNumber = weightNumbers;     // controls if weight number will be shown
 
-    qDebug()<< "GraphicsEdge::GraphicsEdge():  "
-            << source->nodeNumber()
-            << "->"
-            << target->nodeNumber()
-            <<" = " << m_weight
-            <<" label " << m_label
-            <<" edgeType " << m_edgeDirType;
+//    qDebug()<< "Constructed graphics edge:"
+//            << source->nodeNumber()
+//            << "->"
+//            << target->nodeNumber()
+//            <<" = " << m_weight
+//           <<" label " << m_label
+//          <<" edgeType " << m_edgeDirType;
 
     if (m_drawWeightNumber) {
         addWeightNumber();
@@ -120,16 +110,19 @@ GraphicsEdge::GraphicsEdge(GraphicsWidget *gw,
     setZValue(ZValueEdge);
 
     setBoundingRegionGranularity(0);
-    // When using QGraphicsItem::ItemCoordinateCache
-    // we should unset it before exporting canvas content to PDF.
-    //setCacheMode (QGraphicsItem::ItemCoordinateCache);
-    //setCacheMode(QGraphicsItem::DeviceCoordinateCache);
+
+    // Leave the default cache option (NoCache)
+    // setCacheMode(QGraphicsItem::NoCache);
 
     adjust();
 }
 
 
 
+/**
+ * @brief Toggles displaying edge arrow
+ * @param drawArrows
+ */
 void GraphicsEdge::showArrows(const bool &drawArrows){
     prepareGeometryChange();
     m_drawArrows=drawArrows;
@@ -138,27 +131,40 @@ void GraphicsEdge::showArrows(const bool &drawArrows){
 
 
 
+/**
+ * @brief Removes any references to this edge in source and target nodes.
+ */
 void GraphicsEdge::removeRefs(){
-    qDebug("GraphicsEdge: removeRefs()");
-    source->deleteOutLink(this);
-    target->deleteInLink(this);
+//    qDebug() << "Removing edge refs...";
+    source->removeOutEdge(this);
+    target->removeInEdge(this);
 }
 
 
+/**
+ * @brief Sets the edge color
+ * @param str
+ */
 void GraphicsEdge::setColor( const QString &str) {
     m_color=QColor(str);
     prepareGeometryChange();
 }
 
 
-
+/**
+ * @brief Returns the edge QColor.
+ * @return
+ */
 QColor GraphicsEdge::color() const{
     return m_color;
 }
 
 
 /**
- * @brief Called from Graph::graphSaveToPajekFormat()
+ * @brief Returns the edge color in pajek-accepted format
+ *
+ * Called from Graph
+ *
  * @return
  */
 QString GraphicsEdge::colorToPajek() {
@@ -169,13 +175,16 @@ QString GraphicsEdge::colorToPajek() {
     return m_colorStr;
 }
 
+
 /**
- * @brief Called from MW when user wants to change an edge's weight.
-    Updates both the width and the weightNumber
+ * @brief Changes the edge weight - Updates both the width and the weightNumber
+ *
+ * Called from MW when user wants to change an edge's weight.
+
  * @param w
  */
 void GraphicsEdge::setWeight(const qreal &w) {
-    qDebug() << "GraphicsEdge::setWeight() " << w;
+//    qDebug() << "Setting edge weight:" << w;
     prepareGeometryChange();
     m_weight = w;
     if ( fabs(m_weight) > 1  )  {
@@ -194,18 +203,20 @@ void GraphicsEdge::setWeight(const qreal &w) {
  * @return
  */
 qreal GraphicsEdge::weight() const {
-    qDebug() << "GraphicsEdge::weight() " << m_weight;
     return m_weight;
 }
 
 
+/**
+ * @brief Adds a graphics edge weight to this edge
+ */
 void GraphicsEdge::addWeightNumber (){
     // create edge weight item
     double x = -20 + ( source->x() + target->x() ) / 2.0;
     double y = -20 + ( source->y() + target->y() ) / 2.0;
     weightNumber = new  GraphicsEdgeWeight (this, 7, QString::number(m_weight) );
-    weightNumber-> setPos(x,y);
-    weightNumber-> setDefaultTextColor (m_color);
+    weightNumber->setPos(x,y);
+    weightNumber->setDefaultTextColor (m_color);
     m_drawWeightNumber = true;
 }
 
@@ -217,9 +228,9 @@ void GraphicsEdge::addWeightNumber (){
 void GraphicsEdge::setWeightNumberVisibility (const bool &toggle) {
     if (m_drawWeightNumber) {
         if (toggle)
-            weightNumber ->show();
+            weightNumber->show();
         else
-            weightNumber ->hide();
+            weightNumber->hide();
     }
     else{
         if (toggle)
@@ -232,11 +243,14 @@ void GraphicsEdge::setWeightNumberVisibility (const bool &toggle) {
 
 
 /**
- * @brief Called from MW when user wants to change an edge's label
+ * @brief Changes the edge label.
+ *
+ * Called from MW when user wants to change an edge's label
+ *
  * @param label
  */
 void GraphicsEdge::setLabel(const QString &label) {
-    qDebug() << "GraphicsEdge::setLabel() " << label;
+//    qDebug() << "Setting graphics edge label:" << label;
     prepareGeometryChange();
     m_label = label;
     if (m_drawLabel)
@@ -244,27 +258,38 @@ void GraphicsEdge::setLabel(const QString &label) {
 }
 
 
+/**
+ * @brief Returns the edge label text
+ * @return QString
+ */
 QString GraphicsEdge::label() const {
     return m_label;
 }
 
 
+/**
+ * @brief Adds a graphics edge label to this edge
+ */
 void GraphicsEdge::addLabel (){
     // create edge label item
     double x =  5+ ( source->x() + target->x() ) / 2.0;
     double y =  5+ ( source->y() + target->y() ) / 2.0;
     edgeLabel = new  GraphicsEdgeLabel (this, 7, m_label );
-    edgeLabel-> setPos(x,y);
-    edgeLabel-> setDefaultTextColor (m_color);
+    edgeLabel->setPos(x,y);
+    edgeLabel->setDefaultTextColor (m_color);
     m_drawLabel = true;
 }
 
+/**
+ * @brief Toggles the graphics edge label visibility
+ * @param toggle
+ */
 void GraphicsEdge::setLabelVisibility (const bool &toggle) {
     if (m_drawLabel) {
         if (toggle)
-            edgeLabel ->show();
+            edgeLabel->show();
         else
-            edgeLabel ->hide();
+            edgeLabel->hide();
     }
     else{
         if (toggle)
@@ -274,18 +299,25 @@ void GraphicsEdge::setLabelVisibility (const bool &toggle) {
 }
 
 
-
-
+/**
+ * @brief Returns the source node of this graphics edge
+ * @return
+ */
 GraphicsNode *GraphicsEdge::sourceNode() const {
     return source;
 }
 
 
+/**
+ * @brief Sets the source node of this graphics edge
+ * @param node
+ */
 void GraphicsEdge::setSourceNode(GraphicsNode *node) {
     source = node;
     adjust();
 }
 
+
 /**
  * @brief Called from graphicsNode to update edge offset from source node (i.e. when node size changes)
  * @param offset
@@ -295,6 +327,7 @@ void GraphicsEdge::setSourceNodeSize(const int &size){
     adjust();
 }
 
+
 /**
  * Returns the source node number
  * @return int
@@ -304,11 +337,19 @@ int GraphicsEdge::sourceNodeNumber () {
 }
 
 
+/**
+ * @brief Returns the target node.
+ * @return
+ */
 GraphicsNode *GraphicsEdge::targetNode() const {
     return target;
 }
 
 
+/**
+ * @brief Sets the target node.s
+ * @param node
+ */
 void GraphicsEdge::setTargetNode(GraphicsNode *node){
     target = node;
     adjust();
@@ -343,17 +384,29 @@ void GraphicsEdge::setMinimumOffsetFromNode(const int &offset) {
 }
 
 
-
+/**
+ * @brief Returns the horizontal difference between target and source nodes.
+ * @return
+ */
 qreal GraphicsEdge::dx() const
 {
     return target->x() - source->x();
 }
 
+/**
+ * @brief Returns the vertical difference between target and source nodes.
+ * @return
+ */
 qreal GraphicsEdge::dy() const
 {
     return target->y() - source->y();
 }
 
+
+/**
+ * @brief Returns the euclidean length of the edge
+ * @return
+ */
 qreal GraphicsEdge::length() const
 { return sqrt ( dx() * dx()  + dy() * dy() ) ; }
 
@@ -365,17 +418,17 @@ qreal GraphicsEdge::length() const
  * make the edge weight appear on the centre of the edge
  */
 void GraphicsEdge::adjust(){
-   // qDebug() << "GraphicsEdge::adjust()";
+    // qDebug() << "GraphicsEdge::adjust()";
     if (!source || !target) {
         return;
     }
 
-//    QLineF line(source->x(), source->y(), target->x(), target->y());
+    //    QLineF line(source->x(), source->y(), target->x(), target->y());
     //QPointF edgeOffset;
 
     //line_length = line.length();
-//    line_dx = line.dx();
-//    line_dy = line.dy();
+    //    line_dx = line.dx();
+    //    line_dy = line.dy();
 
     line_length = length();
     line_dx = dx();
@@ -390,8 +443,8 @@ void GraphicsEdge::adjust(){
 
     prepareGeometryChange();
 
-//    sourcePoint = line.p1() + edgeOffset ;
-//    targetPoint = line.p2() - edgeOffset ;
+    //    sourcePoint = line.p1() + edgeOffset ;
+    //    targetPoint = line.p2() - edgeOffset ;
 
     sourcePoint = source->pos() + edgeOffset ;
     targetPoint = target->pos() - edgeOffset ;
@@ -427,8 +480,8 @@ void GraphicsEdge::adjust(){
     else { //self-link
         QPointF c1 = QPointF( targetPoint.x() -30,  targetPoint.y() -30 );
         QPointF c2 = QPointF( targetPoint.x() +30,  targetPoint.y() -30 );
-//        qDebug()<< "*** GraphicsEdge::paint(). Constructing a bezier self curve c1 "
-//                <<c1.x()<<","<<c1.y()  << " and c2 "<<c2.x()<<","<<c2.y();
+        //        qDebug()<< "*** GraphicsEdge::paint(). Constructing a bezier self curve c1 "
+        //                <<c1.x()<<","<<c1.y()  << " and c2 "<<c2.x()<<","<<c2.y();
         path.cubicTo( c1, c2, targetPoint);
     }
 
@@ -446,51 +499,51 @@ void GraphicsEdge::adjust(){
             angle = M_PI_X_2 - angle;
 
 
-//            qDebug() << "*** GraphicsEdge::paint(). Constructing arrows. "
-//                        "First Arrow at target node"
-//                     << "target-source: " << line_dx
-//                     << " length: " << line_length
-//                     << " angle: "<< angle;
+        //            qDebug() << "*** GraphicsEdge::paint(). Constructing arrows. "
+        //                        "First Arrow at target node"
+        //                     << "target-source: " << line_dx
+        //                     << " length: " << line_length
+        //                     << " angle: "<< angle;
 
-            QPointF destArrowP1 = targetPoint + QPointF(sin(angle - M_PI_3) * m_arrowSize,
-                                                        cos(angle - M_PI_3) * m_arrowSize);
-            QPointF destArrowP2 = targetPoint + QPointF(sin(angle - M_PI + M_PI_3) * m_arrowSize,
-                                                        cos(angle - M_PI + M_PI_3) * m_arrowSize);
-//            qDebug() << "*** GraphicsEdge::paint() destArrowP1 "
-//                     <<  destArrowP1.x() << "," << destArrowP1.y()
-//                      << "  destArrowP2 " <<  destArrowP2.x() << "," << destArrowP2.y();
+        QPointF destArrowP1 = targetPoint + QPointF(sin(angle - M_PI_3) * m_arrowSize,
+                                                    cos(angle - M_PI_3) * m_arrowSize);
+        QPointF destArrowP2 = targetPoint + QPointF(sin(angle - M_PI + M_PI_3) * m_arrowSize,
+                                                    cos(angle - M_PI + M_PI_3) * m_arrowSize);
+        //            qDebug() << "*** GraphicsEdge::paint() destArrowP1 "
+        //                     <<  destArrowP1.x() << "," << destArrowP1.y()
+        //                      << "  destArrowP2 " <<  destArrowP2.x() << "," << destArrowP2.y();
+
+        path.addPolygon ( QPolygonF()
+                          << targetPoint
+                          << destArrowP1
+                          << destArrowP2
+                          << targetPoint
+                          );
+
+        if (m_edgeDirType == EdgeType::Undirected || m_edgeDirType == EdgeType::Reciprocated ) {
+            //            qDebug() << "**** GraphicsEdge::paint() This edge is SYMMETRIC! "
+            //                     << " So, we need to create Arrow at src node as well";
+            QPointF srcArrowP1 = sourcePoint + QPointF(sin(angle +M_PI_3) * m_arrowSize,
+                                                       cos(angle +M_PI_3) * m_arrowSize);
+            QPointF srcArrowP2 = sourcePoint + QPointF(sin(angle +M_PI - M_PI_3) * m_arrowSize,
+                                                       cos(angle +M_PI - M_PI_3) * m_arrowSize);
 
             path.addPolygon ( QPolygonF()
-                                 << targetPoint
-                                 << destArrowP1
-                                 << destArrowP2
-                                 << targetPoint
-                                 );
+                              << sourcePoint
+                              << srcArrowP1
+                              << srcArrowP2
+                              <<sourcePoint
+                              );
 
-            if (m_edgeDirType == EdgeType::Undirected || m_edgeDirType == EdgeType::Reciprocated ) {
-    //            qDebug() << "**** GraphicsEdge::paint() This edge is SYMMETRIC! "
-    //                     << " So, we need to create Arrow at src node as well";
-                QPointF srcArrowP1 = sourcePoint + QPointF(sin(angle +M_PI_3) * m_arrowSize,
-                                                           cos(angle +M_PI_3) * m_arrowSize);
-                QPointF srcArrowP2 = sourcePoint + QPointF(sin(angle +M_PI - M_PI_3) * m_arrowSize,
-                                                           cos(angle +M_PI - M_PI_3) * m_arrowSize);
-
-                path.addPolygon ( QPolygonF()
-                                     << sourcePoint
-                                     << srcArrowP1
-                                     << srcArrowP2
-                                     <<sourcePoint
-                                     );
-
-            }
-            else {
-                // qDebug() << "*** GraphicsEdge::paint() Not symmetric edge. Finish";
-            }
+        }
+        else {
+            // qDebug() << "*** GraphicsEdge::paint() Not symmetric edge. Finish";
+        }
 
 
     }
     else {
-//        qDebug()<< "*** GraphicsEdge::paint(). This edge is self-link - CONTINUE!";
+        //        qDebug()<< "*** GraphicsEdge::paint(). This edge is self-link - CONTINUE!";
     }
 
 
@@ -509,10 +562,10 @@ void GraphicsEdge::adjust(){
  */
 QPainterPath GraphicsEdge::shape () const {
     //qDebug()<<"GraphicsEdge::shape()";		//too many debug messages...
-//    QPainterPath m_path_shape = m_path;
-//    m_path_shape.addPath(m_path.translated(1,1));
-//    m_path_shape.addPath(m_path.translated(-1,-1));
-//    return m_path_shape;
+    //    QPainterPath m_path_shape = m_path;
+    //    m_path_shape.addPath(m_path.translated(1,1));
+    //    m_path_shape.addPath(m_path.translated(-1,-1));
+    //    return m_path_shape;
     return m_path;
 } 
 
@@ -524,7 +577,7 @@ QPainterPath GraphicsEdge::shape () const {
  * @return
  */
 QRectF GraphicsEdge::boundingRect() const {
-   //qDebug()<<"GraphicsEdge::boundingRect()";		//too many debug messages...
+    //qDebug()<<"GraphicsEdge::boundingRect()";		//too many debug messages...
     if (!source || !target)
         return QRectF();
     return m_path.controlPointRect();
@@ -532,15 +585,15 @@ QRectF GraphicsEdge::boundingRect() const {
 
 
 /**
- * @brief Changes the direction type of edge A -> B
+ * @brief Changes the direction type of edge A->B
   */
 void GraphicsEdge::setDirectionType(const int &dirType){
-    qDebug()<< "GraphicsEdge::setDirectionType() - "
-            << source->nodeNumber()
-            << "->"
-            << target->nodeNumber()
-            << "direction type"
-            << dirType;
+//    qDebug()<< "Edge"
+//            << source->nodeNumber()
+//            << "->"
+//            << target->nodeNumber()
+//            << "new direction type"
+//            << dirType;
     prepareGeometryChange();
     m_edgeDirType = dirType;
     m_drawArrows = true;
@@ -561,18 +614,26 @@ int GraphicsEdge::directionType() {
 
 
 
-
+/**
+ * @brief Sets the PenStyle of this edge
+ * @param style
+ */
 void GraphicsEdge::setStyle( const Qt::PenStyle  &style ) {
     m_style = style;
 }
 
+
+/**
+ * @brief Returns the PenStyle of this edge
+ * @return
+ */
 Qt::PenStyle GraphicsEdge::style() const{
     return m_style;
 
 }
 
 /**
- * @brief GraphicsEdge::pen
+ * @brief Returns the QPen for this edge -- the pen changes when the edge state changes/
  * @return
  */
 QPen GraphicsEdge::pen() const {
@@ -600,7 +661,7 @@ QPen GraphicsEdge::pen() const {
 
 
 /**
- * @brief GraphicsEdge::setState
+ * @brief Sets the edge state
  * @param state
  */
 void GraphicsEdge::setState(const int &state) {
@@ -610,7 +671,8 @@ void GraphicsEdge::setState(const int &state) {
 
 
 /**
- * @brief GraphicsEdge::paint
+ * @brief Pains the edge
+ *
  * @param painter
  * @param option
  */
@@ -619,29 +681,29 @@ void GraphicsEdge::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
         return;
 
     //qDebug() <<"@@@ GraphicsEdge::paint() on" << painter->paintEngine()->type();
-     //painter->setClipRect();
+    //painter->setClipRect();
 
-     //if the edge is being dragged around, darken it!
-     if (option->state & QStyle::State_Selected) {
-         //setZValue(ZValueEdgeHighlighted);
-         setState(EDGE_STATE_HOVER);
-     }
-     else if (option->state & QStyle::State_MouseOver) {
-         if (m_hoverHighlighting) {
-             setZValue(ZValueEdgeHighlighted);
-             setState(EDGE_STATE_HOVER);
-         }
-     }
-     else if (m_state==EDGE_STATE_HIGHLIGHT){
-         if (m_hoverHighlighting) {
-             setZValue(ZValueEdgeHighlighted);
-             setState(EDGE_STATE_HIGHLIGHT);
-         }
-     }
-     else {
-         setZValue(ZValueEdge);
-         setState(EDGE_STATE_REGULAR);
-     }
+    //if the edge is being dragged around, darken it!
+    if (option->state & QStyle::State_Selected) {
+        //setZValue(ZValueEdgeHighlighted);
+        setState(EDGE_STATE_HOVER);
+    }
+    else if (option->state & QStyle::State_MouseOver) {
+        if (m_hoverHighlighting) {
+            setZValue(ZValueEdgeHighlighted);
+            setState(EDGE_STATE_HOVER);
+        }
+    }
+    else if (m_state==EDGE_STATE_HIGHLIGHT){
+        if (m_hoverHighlighting) {
+            setZValue(ZValueEdgeHighlighted);
+            setState(EDGE_STATE_HIGHLIGHT);
+        }
+    }
+    else {
+        setZValue(ZValueEdge);
+        setState(EDGE_STATE_REGULAR);
+    }
     // set painter pen to correct edge pen
     painter->setPen(pen());
 
@@ -698,18 +760,16 @@ QVariant GraphicsEdge::itemChange(GraphicsItemChange change, const QVariant &val
  * @return
  */
 qreal GraphicsEdge::width() const{
-//    if ( fabs(m_weight) > 1  )  {
-//        return 1+log ( 1+ log(fabs(m_weight) )) ;
-//    }
-//    return fabs(m_weight) ;
     return m_width;
 }
 
 
 
 /**
- * @brief Called from GraphicsNode to change the edge state and highlight it.
- * This is done, when the user hovers over the node.
+ * @brief Toggles the highlighted state of the the edge, if highlighting is allowed.
+ *
+ * Called from GraphicsNode when the user hovers over the node.
+ *
  * @param flag
  */
 void GraphicsEdge::setHighlighted(const bool &flag) {
@@ -727,6 +787,9 @@ void GraphicsEdge::setHighlighted(const bool &flag) {
 
 /**
  * @brief Toggles edge highlighting on or off
+ *
+ * If enabled, the edge can be highlighted.
+ *
  * @param toggle
  */
 void GraphicsEdge::setHighlighting(const bool &toggle) {
@@ -737,30 +800,37 @@ void GraphicsEdge::setHighlighting(const bool &toggle) {
 
 
 
-/**
- * @brief handles the events of a click on an edge
- * @param event
- */
-void GraphicsEdge::mousePressEvent(QGraphicsSceneMouseEvent *e) {
-    qDebug() << "GraphicsEdge::mousePressEvent() - click on an edge ";
-    //setClicked();
-    QGraphicsItem::mousePressEvent(e);
-}
+///**
+// * @brief handles the events of a click on an edge
+// * @param event
+// */
+//void GraphicsEdge::mousePressEvent(QGraphicsSceneMouseEvent *e) {
+//    qDebug() << "GraphicsEdge::mousePressEvent() - click on an edge ";
+//    //setClicked();
+//    QGraphicsItem::mousePressEvent(e);
+//}
 
 
 
 
 GraphicsEdge::~GraphicsEdge(){
-    qDebug() << "GraphicsEdge::~GraphicsEdge() - self-destructing edge " << sourceNodeNumber()<< "->" << targetNodeNumber();
+//    qDebug() << "self-destructing edge:"
+//             << sourceNodeNumber()<< "->" << targetNodeNumber()
+//             << "will remove refs first...";
 
     removeRefs();
+
+//    qDebug() << "removing edge weight number, if any...";
     if (m_drawWeightNumber)
         graphicsWidget->removeItem(weightNumber);
+
+//    qDebug() << "removing edge label, if any...";
     if (m_drawLabel)
         graphicsWidget->removeItem(edgeLabel);
 
     this->hide();
 
+//    qDebug() << "calling GW removeItem for this edge";
     graphicsWidget->removeItem(this);
 
 
