@@ -1,31 +1,21 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
+/**
+ * @file graphicsguide.cpp
+ * @brief Implements the GraphicsGuide class for drawing guides in the network graph visualization.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
-                         graphicsguide.cpp  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
 
 #include "graphicsguide.h"
+
 #include "graphicswidget.h"
 
 GraphicsGuide::GraphicsGuide ( GraphicsWidget *gw,
