@@ -1,29 +1,17 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
-
-                        graphicsnode.cpp  -  description
-                        -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
+/**
+ * @file graphicsnode.cpp
+ * @brief Implements the GraphicsNode class for rendering nodes in the network graph visualization.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
 
 #include "graphicsnode.h"
@@ -41,7 +29,28 @@
 
 
 
-
+/**
+ * @brief Constructs a new node object (which is a graphics item)
+ *
+ * @param gw
+ * @param num
+ * @param size
+ * @param color
+ * @param shape
+ * @param iconPath
+ * @param showNumbers
+ * @param numbersInside
+ * @param numberColor
+ * @param numberSize
+ * @param numDistance
+ * @param showLabels
+ * @param label
+ * @param labelColor
+ * @param labelSize
+ * @param labelDistance
+ * @param edgeHighlighting
+ * @param p
+ */
 GraphicsNode::GraphicsNode ( GraphicsWidget* gw,
                              const int &num,
                              const int &size,
@@ -62,16 +71,13 @@ GraphicsNode::GraphicsNode ( GraphicsWidget* gw,
                              QPointF p
                              ) : graphicsWidget (gw)
 {
-    qDebug()<<"GraphicsNode::GraphicsNode() - New node:"<< num << "initializing...";
-    graphicsWidget->scene()->addItem(this); //Without this nodes don't appear on the screen...
+
+    graphicsWidget->scene()->addItem(this); // Without this nodes don't appear on the screen...
 
     setFlags(ItemSendsGeometryChanges | ItemIsSelectable | ItemIsMovable );
 
-    //QT < 4.6 if a cache mode is set, nodes do not respond to hover events
-    //setCacheMode(QGraphicsItem::ItemCoordinateCache);
-
-    //QT < 4.6 if a cache mode is set, nodes do not respond to hover events
-    setCacheMode(QGraphicsItem::NoCache);
+    // Leave the default cache option (NoCache)
+    // setCacheMode(QGraphicsItem::NoCache);
 
     setAcceptHoverEvents(true);
 
@@ -81,8 +87,9 @@ GraphicsNode::GraphicsNode ( GraphicsWidget* gw,
     m_shape=shape;
     m_iconPath = iconPath;
 
-    m_col_str=color;
-    m_col=QColor(color);
+    m_col_orig=m_col=QColor(color);
+
+    m_col_outline = QColor(0,0,0,50);
 
     m_hasNumber=showNumbers;
     m_hasNumberInside = numbersInside;
@@ -111,57 +118,84 @@ GraphicsNode::GraphicsNode ( GraphicsWidget* gw,
     setShape(m_shape,m_iconPath);
 
     setPos(p);
-    qDebug()<< "GraphicsNode::GraphicsNode() - Created at pos:"  << x()<<","<<y()
-            << "m_numSize" << m_numSize;
+
+    qDebug()<< "Constructed new node" << nodeNumber() << "at pos:" << x()<<"x"<<y()
+            << "size:" << m_numSize;
 
 } 
 
 
 
 /**
- * @brief Changes the color of the node
- * @param color string
+ * @brief Changes the color of the node. The new color name can be in one of these formats:
+ *
+ * - #RGB (each of R, G, and B is a single hex digit)
+ * - #RRGGBB
+ * - #AARRGGBB (Since 5.2)
+ * - #RRRGGGBBB
+ * - #RRRRGGGGBBBB
+ * - A name from the list of colors defined in the list of SVG color keyword names provided by the WWW Consortium;
+ *   for example, "steelblue" or "gainsboro". These color names work on all platforms.
+ *   Note that these color names are not the same as defined by the Qt::GlobalColor enums, e.g. "green" and Qt::green
+ *   does not refer to the same color.
+ * - transparent - representing the absence of a color.
+ *
+ * @param colorStr
  */
-void GraphicsNode::setColor(const QString &colorStr) {
-    qDebug()<< "GraphicsNode::setColor() - newColorStr:"  << colorStr;
+void GraphicsNode::setColor(const QString &colorName) {
+//    qDebug()<< "Changing the node color to named color:" << colorName << "setting mcol:" << QColor(colorName);
     prepareGeometryChange();
-    m_col=QColor(colorStr);
+    m_col_orig=m_col=QColor(colorName);
+//    qDebug()<< "Calling update()";
     update();
 }
 
 
 /**
  * @brief Changes the color of the node (overloaded)
+ *
  * Also used when the user searches for a node
+ *
  * @param color
  */
 void GraphicsNode::setColor(QColor color){
-    qDebug()<< "GraphicsNode::setColor() - new QColor:"  << color;
+//    qDebug()<< "Changing the node Qcolor to:" << color;
     prepareGeometryChange();
     m_col=color;
-    m_col_str = m_col.name();
+//    qDebug()<< "Calling update()";
     update();
 }
 
 
+/**
+ * @brief Returns the node color in the format "#RRGGBB".
+ *
+ * @return QString
+ */
 QString GraphicsNode::color() {
-    return m_col_str;
+    return m_col.name();
 }
 
 
-/** Sets the size of the node */
+
+/**
+ * @brief Changes the size of the node
+ *
+ * @param size
+ */
 void GraphicsNode::setSize(const int &size){
-    qDebug()<<"GraphicsNode::setSize()";
+//    qDebug()<< "Changing the node size to:" << size;
     prepareGeometryChange();
     m_size=size;
-    foreach (GraphicsEdge *edge, inEdgeList) {
-        qDebug("GraphicsNode: updating edges in inEdgeList");
+    for (GraphicsEdge *edge: inEdgeList) {
+//        qDebug()<< "Informing inbound edges";
         edge->setTargetNodeSize(size);
     }
-    foreach (GraphicsEdge *edge, outEdgeList) {
-        qDebug("GraphicsNode: updating edges in outEdgeList");
+    for (GraphicsEdge *edge: outEdgeList) {
+//        qDebug()<< "Informing oubound edges";
         edge->setSourceNodeSize(size);
     }
+//    qDebug()<< "calling setShape()";
     setShape(m_shape);
 }
 
@@ -170,7 +204,7 @@ void GraphicsNode::setSize(const int &size){
 
 /**
  * @brief Returns the esoteric size of the node.
- * Used by GraphicsEdge::GraphicsEdge()
+ *
  * @return
  */
 int GraphicsNode::size() const{
@@ -180,18 +214,19 @@ int GraphicsNode::size() const{
 
 
 
-
-
 /**
  * @brief Sets the shape of the node and prepares the corresponding QPainterPath
- * m_path which will be drawn by our painter in GraphicsNode::paint().
+ * m_path which will be drawn by our painter (see paint()).
+ *
  * The only exception is when the shape is 'custom'. In that case, the painter
  * will paint a pixmap with the custom node icon (loaded from iconPath).
  * However, even in that case we are still creating a QPainterPath, because this
  * is needed by QGraphicsNode::shape() function which is responsible for collision
  * detection and needs to return a path with an accurate outline of the item's shape.
  * Called every time the user needs to change the shape of an node.
+ *
  * @param shape
+ * @param iconPath
  */
 void GraphicsNode::setShape(const QString shape, const QString &iconPath) {
 
@@ -199,10 +234,10 @@ void GraphicsNode::setShape(const QString shape, const QString &iconPath) {
 
     m_shape=shape;
 
-    qDebug()<< "GraphicsNode::setShape() - Node:" << nodeNumber()
-            << "shape:" << m_shape
-            << "iconPath" << iconPath
-            << "pos:"<<  x() << "," <<  y();
+//    qDebug()<< "Setting shape for node:" << nodeNumber()
+//            << "shape:" << m_shape
+//            << "iconPath" << iconPath
+//            << "pos:"<<  x() << "," <<  y();
 
     QPainterPath path;
 
@@ -293,25 +328,25 @@ void GraphicsNode::setShape(const QString shape, const QString &iconPath) {
 
 /**
  * @brief Returns the shape of the node as a path in local coordinates.
+ *
  * The shape is used for many things, including collision detection, hit tests,
  * and for the QGraphicsScene::items() functions.
  * We could ommit reimplementing this and have the default QGraphicsItem::shape()
  * return a simple rectangular shape through boundingRect() but we opt to return
  * an accurate outline of the item's shape.
+ *
  * @return
  */
 QPainterPath GraphicsNode::shape() const {
-
-    //qDebug() << "GraphicsNode::shape()";
-
     return (m_path);
-
 }
 
 
 /**
- * @brief Returns the bounding rectangle of the node:
- * The rectangle where all painting will take place.
+ * @brief Returns the bounding rectangle of the node.
+ *
+ * The bounding rectangle is the area where all painting will take place.
+ *
  * @return
  */
 QRectF GraphicsNode::boundingRect() const {
@@ -324,22 +359,24 @@ QRectF GraphicsNode::boundingRect() const {
 
 /**
  * @brief Does the actual painting using the QPainterPath created by the setShape()
+ *
  * Called by GraphicsView and GraphicsNode methods in every update()
+ *
  * @param painter
  * @param option
  */
 void GraphicsNode::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *) {
     //	painter->setClipRect( option->exposedRect );
 
-    //qDebug()<< "GraphicsNode::paint() " << m_col;
+//    qDebug()<< "GraphicsNode::paint() - m_col:" << m_col << "color name:" << m_col.name();
 
     if (option->state & QStyle::State_MouseOver) {
-      //  qDebug()<< "GraphicsNode::paint() mouse over " << m_col;
+//        qDebug()<< "Highlighting node because of mouse hover ";
         painter->setBrush(m_col.darker(120));
         setZValue(ZValueNodeHighlighted);
     }
     else {
-        //qDebug()<< "GraphicsNode::paint() - no mouse over " << m_col;
+//        qDebug()<< "GraphicsNode::paint() - no mouse over " << m_col;
         painter->setBrush(m_col);
         setZValue(ZValueNode);
     }
@@ -353,15 +390,14 @@ void GraphicsNode::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
               m_shape == "bugs"    ||
               m_shape == "heart"   ||
               m_shape == "dice"     ) {
-        // See:
-        // https://techbase.kde.org/Development/Tutorials/Graphics/Performance
+
 //        QImage image(m_iconPath);
 //        painter->drawImage(QRectF(-m_size, -m_size, 2*m_size, 2*m_size) , image);
         QPixmap pix(m_iconPath);
         painter->drawPixmap(-m_size, -m_size, 2*m_size, 2*m_size, pix);
     }
     else {
-        painter->setPen(QPen(QColor("#222"), 0));
+        painter->setPen(QPen(m_col_outline, 0));
         painter->drawPath (m_path);
     }
 
@@ -404,19 +440,21 @@ void GraphicsNode::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
  */
 QVariant GraphicsNode::itemChange(GraphicsItemChange change, const QVariant &value) {
 
+//    qDebug()<<"GraphicsNode::itemChange - change:" << change<< "value:" << value << "m_col" << m_col.name();
+
     switch (change) {
     case ItemPositionHasChanged: {
         //setCacheMode( QGraphicsItem::ItemCoordinateCache );
-        foreach (GraphicsEdge *edge, inEdgeList)  //Move each inEdge of this node
+        for (GraphicsEdge *edge: inEdgeList)  //Move each inEdge of this node
             edge->adjust();
-        foreach (GraphicsEdge *edge, outEdgeList) //Move each outEdge of this node
+        for (GraphicsEdge *edge: outEdgeList) //Move each outEdge of this node
             edge->adjust();
         //Move its graphic number
         if ( m_hasNumber )
         {
             if (!m_hasNumberInside) 	{ //move it outside
-                m_number -> setZValue(ZValueNodeNumber);
-                m_number -> setPos( m_size+m_numberDistance, 0);
+                m_number->setZValue(ZValueNodeNumber);
+                m_number->setPos( m_size+m_numberDistance, 0);
             }
         }
         if (m_hasLabel) {
@@ -425,21 +463,22 @@ QVariant GraphicsNode::itemChange(GraphicsItemChange change, const QVariant &val
         break;
     }
     case ItemEnabledHasChanged:{
-        qDebug() << "GraphicsNode::itemChange - enabled changed";
+//        qDebug() << "Node item has been enabled";
         break;
     }
     case ItemSelectedHasChanged:{
+//         qDebug() << "Node ItemSelectedHasChanged";
         if (value.toBool()) {
             setZValue(ZValueNodeHighlighted);
             m_size_orig = m_size;
             setSize(m_size * 2 - 1);
-
+            m_col_orig = m_col;
             setColor(m_col.darker(120));
 
             if (m_edgeHighLighting) {
-                foreach (GraphicsEdge *edge, inEdgeList)
+                for (GraphicsEdge *edge: inEdgeList)
                     edge->setHighlighted(true);
-                foreach (GraphicsEdge *edge, outEdgeList)
+                for (GraphicsEdge *edge: outEdgeList)
                     edge->setHighlighted(true);
             }
 
@@ -447,12 +486,12 @@ QVariant GraphicsNode::itemChange(GraphicsItemChange change, const QVariant &val
         else{
             setZValue(ZValueNode);
             setSize(m_size_orig);
-            setColor(m_col);
+            setColor(m_col_orig);
 
             if (m_edgeHighLighting) {
-                    foreach (GraphicsEdge *edge, inEdgeList)
+                    for (GraphicsEdge *edge: inEdgeList)
                         edge->setHighlighted(false);
-                    foreach (GraphicsEdge *edge, outEdgeList)
+                    for (GraphicsEdge *edge: outEdgeList)
                         edge->setHighlighted(false);
             }
         }
@@ -472,35 +511,35 @@ QVariant GraphicsNode::itemChange(GraphicsItemChange change, const QVariant &val
 
 
 
-/** handles the events of a click on a node */
-void GraphicsNode::mousePressEvent(QGraphicsSceneMouseEvent *event) {
-    QGraphicsItem::mousePressEvent(event);
-}
+
+//void GraphicsNode::mousePressEvent(QGraphicsSceneMouseEvent *event) {
+//    QGraphicsItem::mousePressEvent(event);
+//}
 
 
-void GraphicsNode::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
-    update();
-    QGraphicsItem::mouseReleaseEvent(event);
-}
+//void GraphicsNode::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
+//    update();
+//    QGraphicsItem::mouseReleaseEvent(event);
+//}
 
-/**
- * @brief GraphicsNode::hoverEnterEvent
- * on hover on node, it highlights all connected edges
- * @param event
- */
-void GraphicsNode::hoverEnterEvent(QGraphicsSceneHoverEvent *event) {
+///**
+// * @brief GraphicsNode::hoverEnterEvent
+// * on hover on node, it highlights all connected edges
+// * @param event
+// */
+//void GraphicsNode::hoverEnterEvent(QGraphicsSceneHoverEvent *event) {
 
-    QGraphicsItem::hoverEnterEvent(event);
-}
+//    QGraphicsItem::hoverEnterEvent(event);
+//}
 
-/**
- * @brief GraphicsNode::hoverLeaveEvent
- * Stops the connected edges highlighting
- * @param event
- */
-void GraphicsNode::hoverLeaveEvent(QGraphicsSceneHoverEvent *event){
-    QGraphicsItem::hoverLeaveEvent(event);
-}
+///**
+// * @brief GraphicsNode::hoverLeaveEvent
+// * Stops the connected edges highlighting
+// * @param event
+// */
+//void GraphicsNode::hoverLeaveEvent(QGraphicsSceneHoverEvent *event){
+//    QGraphicsItem::hoverLeaveEvent(event);
+//}
 
 
 
@@ -509,55 +548,73 @@ void GraphicsNode::setEdgeHighLighting(const bool &toggle) {
 }
 
 /**
- * @brief GraphicsNode::addInLink
+ * @brief Adds an inbound edge to this node
+ *
  * Called from a new connected in-link to acknowloedge itself to this node.
+ *
  * @param edge
  */
-void GraphicsNode::addInLink( GraphicsEdge *edge ) {
-    qDebug() << "GraphicsNode:  addInLink() for "<<  m_num;
+void GraphicsNode::addInEdge( GraphicsEdge *edge ) {
+//    qDebug() << "adding inEdge"<< nodeNumber() << "<-" << edge->sourceNodeNumber();
     inEdgeList.push_back( edge);
-    //qDebug ("GraphicsNode:  %i inEdgeList has now %i edges", m_num, inEdgeList.size());
 }
 
 
-void GraphicsNode::deleteInLink( GraphicsEdge *link ){
-    qDebug () << "GraphicsNode::deleteInLink() - to " <<  m_num
-              << " inEdgeList size: " << inEdgeList.size();
-    inEdgeList.remove( link );
-    qDebug () << "GraphicsNode::deleteInLink() - deleted to " <<  m_num
-              << " inEdgeList size: " << inEdgeList.size();
+/**
+ * @brief Removes the inbound edge from this node
+ * @param link
+ */
+void GraphicsNode::removeInEdge( GraphicsEdge *edge ){
+//    qDebug () << "node" << nodeNumber()
+//             << "Removing inEdge"<< nodeNumber() << "<-" << edge->sourceNodeNumber()
+//              << "inEdgeList size:" << inEdgeList.size();
+    inEdgeList.remove( edge );
 }
 
 
-
-void GraphicsNode::addOutLink( GraphicsEdge *edge ) {
-    qDebug("GraphicsNode: addOutLink()");
-    outEdgeList.push_back( edge);
-    //	qDebug ("GraphicsNode: outEdgeList has now %i edges", outEdgeList.size());
+/**
+ * @brief Adds a outbound edge to this node
+ *
+ * Called from the edge itself.
+ *
+ * @param edge
+ */
+void GraphicsNode::addOutEdge( GraphicsEdge *edge ) {
+//    qDebug() << "adding outEdge"<< nodeNumber() << "->" << edge->targetNodeNumber();
+    outEdgeList.push_back(edge);
 }
-
 
 
-void GraphicsNode::deleteOutLink(GraphicsEdge *link){
-    qDebug () << "GraphicsNode::deleteOutLink() - from " <<  m_num
-              << " outEdgeList size: " << outEdgeList.size();
-    outEdgeList.remove( link);
-    qDebug () << "GraphicsNode::deleteOutLink() - deleted from " <<  m_num
-              << " outEdgeList size now: " << outEdgeList.size();
+/**
+ * @brief Removes an outbound edge from this node
+ *
+ * @param edge
+ */
+void GraphicsNode::removeOutEdge(GraphicsEdge *edge){
+//    qDebug () << "node" << nodeNumber()
+//             << "Removing outEdge"<< nodeNumber() << "->" << edge->targetNodeNumber()
+//              << "outEdgeList size:" << outEdgeList.size();
+    outEdgeList.remove(edge);
 }
 
 
 
+/**
+ * @brief Creates a graphics label to this node.
+ */
 void GraphicsNode::addLabel ()  {
-    qDebug()<< "GraphicsNode::addLabel()" ;
+//    qDebug()<< "Creating a graphics label for this node." ;
     m_label = new  GraphicsNodeLabel (this, m_labelText, m_labelSize);
-    m_label -> setDefaultTextColor (m_labelColor);
-    m_label -> setPos( m_size, m_labelDistance+m_size);
+    m_label->setDefaultTextColor (m_labelColor);
+    m_label->setPos( m_size, m_labelDistance+m_size);
     m_hasLabel = true;
 }
 
 
-
+/**
+ * @brief Returns the graphics label of the node
+ * @return
+ */
 GraphicsNodeLabel* GraphicsNode::label(){
     if (!m_hasLabel) {
         addLabel();
@@ -565,20 +622,28 @@ GraphicsNodeLabel* GraphicsNode::label(){
     return m_label;
 }
 
+
+/**
+ * @brief Deletes the graphics label of this node.
+ */
 void GraphicsNode::deleteLabel(){
-    qDebug ("GraphicsNode: deleteLabel ");
+//    qDebug()<< "Deleting the graphics label of this node";
     if (m_hasLabel) {
         m_hasLabel=false;
         m_label->hide();
         graphicsWidget->removeItem(m_label);
     }
-    qDebug () << "GraphicsNode::deleteLabel() - finished";
-
 }
 
 
+
+/**
+ * @brief Sets the label of this node
+ *
+ * @param label
+ */
 void GraphicsNode::setLabelText (const QString &label) {
-    qDebug()<< "GraphicsNode::setLabelText()";
+//    qDebug()<< "Changing the label of this node to:" << label;
     prepareGeometryChange();
     m_labelText = label;
     if (m_hasLabel)
@@ -590,8 +655,21 @@ void GraphicsNode::setLabelText (const QString &label) {
 
 
 
+/**
+ * @brief Returns the label of the node
+ * @return QString
+ */
+QString GraphicsNode::labelText ( ) {
+    return m_labelText;
+}
+
+
+/**
+ * @brief Sets the color of the node label.
+ * @param color
+ */
 void GraphicsNode::setLabelColor ( const QString &color) {
-    qDebug()<< "GraphicsNode::setLabelColor()";
+//    qDebug()<< "Changing the color of node label to:" << color;
     prepareGeometryChange();
     m_labelColor= color;
     if (m_hasLabel)
@@ -602,6 +680,10 @@ void GraphicsNode::setLabelColor ( const QString &color) {
 }
 
 
+/**
+ * @brief Toggles the visibiity of the node label
+ * @param toggle
+ */
 void GraphicsNode::setLabelVisibility(const bool &toggle) {
     if (toggle){
         if (m_hasLabel) {
@@ -620,6 +702,11 @@ void GraphicsNode::setLabelVisibility(const bool &toggle) {
     m_hasLabel=toggle;
 }
 
+
+/**
+ * @brief Sets the size of the node label.
+ * @param size
+ */
 void GraphicsNode::setLabelSize(const int &size) {
     m_labelSize = size;
     if (!m_hasLabel) {
@@ -629,18 +716,10 @@ void GraphicsNode::setLabelSize(const int &size) {
 
 }
 
-/**
- * @brief GraphicsNode::labelText
- * @return QString
- */
-QString GraphicsNode::labelText ( ) {
-    return m_labelText;
-}
-
 
 
 /**
- * @brief GraphicsNode::setLabelDistance
+ * @brief Sets the distance of the label from the node.
  * @param distance
  */
 void GraphicsNode::setLabelDistance(const int &distance) {
@@ -655,34 +734,47 @@ void GraphicsNode::setLabelDistance(const int &distance) {
 
 
 
-
+/**
+ * @brief Adds a graphics number to the node
+ */
 void GraphicsNode::addNumber () {
-    qDebug()<<"GraphicsNode::addNumber () " ;
+//    qDebug()<<"Adding node graphics number... " ;
     m_hasNumber=true;
     m_hasNumberInside = false;
     m_number= new  GraphicsNodeNumber ( this, QString::number(m_num), m_numSize);
-    m_number -> setDefaultTextColor (m_numColor);
-    m_number -> setPos(m_size+m_numberDistance, 0);
+    m_number->setDefaultTextColor (m_numColor);
+    m_number->setPos(m_size+m_numberDistance, 0);
 
 }
 
+
+/**
+ * @brief Returns the graphics node number
+ * @return
+ */
 GraphicsNodeNumber* GraphicsNode::number(){
     return m_number;
 }
 
 
+/**
+ * @brief Deletes the graphics node number
+ */
 void GraphicsNode::deleteNumber( ){
-    qDebug () << "GraphicsNode::deleteNumber()";
+//    qDebug () << "Deleting the graphics node number";
     if (m_hasNumber && !m_hasNumberInside) {
         m_number->hide();
         graphicsWidget->removeItem(m_number);
         m_hasNumber=false;
     }
-    qDebug () << "GraphicsNode::deleteNumber() - finished";
 }
 
+/**
+ * @brief Toggles the visibility of graphics node number
+ * @param toggle
+ */
 void GraphicsNode::setNumberVisibility(const bool &toggle) {
-    qDebug() << "GraphicsNode::setNumberVisibility() " << toggle;
+//    qDebug() << "Changing visibility of node number to:" << toggle;
     if (toggle) { //show
         if (!m_hasNumber) {
             m_hasNumber=toggle;
@@ -701,8 +793,12 @@ void GraphicsNode::setNumberVisibility(const bool &toggle) {
 
 }
 
+/**
+ * @brief Toggles displaying node number inside the node
+ * @param toggle
+ */
 void GraphicsNode::setNumberInside (const bool &toggle){
-    qDebug()<<"GraphicsNode::setNumberInside() " << toggle;
+//    qDebug()<<"GraphicsNode::setNumberInside() " << toggle;
     if (toggle) { // set number inside
         deleteNumber();
     }
@@ -745,7 +841,7 @@ void GraphicsNode::setNumberColor(const QString &color) {
             setShape(m_shape);
         }
         else {
-            m_number -> setDefaultTextColor (m_numColor);
+            m_number->setDefaultTextColor (m_numColor);
         }
     }
 
@@ -758,7 +854,7 @@ void GraphicsNode::setNumberColor(const QString &color) {
 void GraphicsNode::setNumberDistance(const int &distance) {
     m_numberDistance = distance;
     if (m_hasNumber && !m_hasNumberInside) {
-        m_number -> setPos( m_size+m_numberDistance, 0);
+        m_number->setPos( m_size+m_numberDistance, 0);
     }
     else if (m_hasNumber && m_hasNumberInside) {
         // do nothing
@@ -774,26 +870,38 @@ void GraphicsNode::setNumberDistance(const int &distance) {
 
 
 GraphicsNode::~GraphicsNode(){
-    qDebug() << "GraphicsNode::~GraphicsNode() - self-destructing node "<< nodeNumber()
-                << "inEdgeList.size = " << inEdgeList.size()
-                << "outEdgeList.size = " << outEdgeList.size();
+//    qDebug() << "Destructing node "<< nodeNumber()
+//                << "- inEdgeList:" << inEdgeList.size()
+//                << "- outEdgeList: " << outEdgeList.size();
 
-    qDebug()<< "GraphicsNode::~GraphicsNode() - removing edges in inEdgeList";
-    foreach (GraphicsEdge *edge, inEdgeList) {  // same as using qDeleteAll
+    // Temp copy in edges
+    list<GraphicsEdge*> temp_inEdgeList = inEdgeList;
+    // Loop over the temp list and call delete for each edge
+    // that will call the edge destructor
+    for (GraphicsEdge *edge: temp_inEdgeList) {
         delete edge;
     }
-    qDebug()<< "GraphicsNode::~GraphicsNode() - removing edges in outEdgeList";
-    foreach (GraphicsEdge *edge, outEdgeList) { // same as using qDeleteAll
+
+    // Temp copy out edges
+    list<GraphicsEdge*> temp_outEdgeList = outEdgeList;
+    for (GraphicsEdge *edge: temp_outEdgeList) {
         delete edge;
     }
+
     if ( m_hasNumber )
         deleteNumber();
+
     if ( m_hasLabel )
         deleteLabel();
-    inEdgeList.clear();
-    outEdgeList.clear();
-    this->hide();
 
+    inEdgeList.clear();
+    temp_inEdgeList.clear();
+
+    outEdgeList.clear();
+    temp_outEdgeList.clear();
+//    qDebug() << "node" << nodeNumber() << "hiding node...";
+    this->hide();
+//    qDebug() << "node" << nodeNumber() << "calling GW removeItem...";
     graphicsWidget->removeItem(this);
 
 }
