@@ -1,29 +1,18 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
- 
-                         graphicsnode.h  -  description
-                          -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
+/**
+ * @file graphicsnode.h
+ * @brief Declares the GraphicsNode class for rendering nodes in the network graph visualization.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
 
 #ifndef GRAPHICSNODE_H
 #define GRAPHICSNODE_H
@@ -50,7 +39,7 @@ static const int ZValueNodeHighlighted = 110;
 /**
 *  This is actually a container-class.
 *  Contains the graphical objects called Nodes,
-*  which are displayed as triangles, boxes, circles, etc, on the canvas.
+*  which are displayed as triangles, boxes, circles, etc, on the GraphicsWidget.
 *  Each node "knows" the others with which she is connected.
 */
 //
@@ -92,10 +81,10 @@ public:
 
     int nodeNumber() {return m_num;}
 
-    void addInLink( GraphicsEdge *edge ) ;
-    void deleteInLink(GraphicsEdge*);
-    void addOutLink( GraphicsEdge *edge ) ;
-    void deleteOutLink(GraphicsEdge*);
+    void addInEdge( GraphicsEdge *edge ) ;
+    void removeInEdge(GraphicsEdge*);
+    void addOutEdge( GraphicsEdge *edge ) ;
+    void removeOutEdge(GraphicsEdge*);
 
     void setSize(const int &);
     int size() const;
@@ -103,7 +92,7 @@ public:
     void setShape (const QString, const QString &iconPath=QString());
     QString nodeShape() {return m_shape;}
 
-    void setColor(const QString &colorStr);
+    void setColor(const QString &colorName);
     void setColor(QColor color);
     QString color ();
 
@@ -132,19 +121,14 @@ public:
 protected:
 
     QVariant itemChange(GraphicsItemChange change, const QVariant &value);
-    void mousePressEvent(QGraphicsSceneMouseEvent *event);
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
-    void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
-    void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
+//    void mousePressEvent(QGraphicsSceneMouseEvent *event);
+//    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
+//    void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
+//    void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
 
 signals: 
 
     void nodeClicked(GraphicsNode*);
-    void startEdge(GraphicsNode *);
-    void adjustOutEdge();
-    void adjustInEdge();
-    void removeOutEdge();
-    void removeInEdge();
 
 
 private:
@@ -153,16 +137,18 @@ private:
     QPainterPath m_path;
     QPointF newPos;
     QPolygonF *m_poly_t;
+    int m_num;
     int m_size, m_size_orig;
     int m_state;
     int m_numSize;
     int m_labelSize;
     int m_numberDistance;
     int m_labelDistance;
-    int m_num;
-    QString  m_shape, m_iconPath;
-    QString m_col_str, m_numColor, m_labelText, m_labelColor;
-    QColor m_col;
+    QString m_shape, m_iconPath;
+    QString m_numColor;
+    QColor m_col, m_col_orig;
+    QColor m_col_outline;
+    QString m_labelText, m_labelColor;
     bool m_hasNumber, m_hasLabel, m_hasNumberInside, m_edgeHighLighting;
     /**Lists of elements attached to this node */
     list<GraphicsEdge*> inEdgeList, outEdgeList;
