@@ -1,39 +1,27 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
- 
-                         graphicswidget.h  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
+/**
+ * @file graphicswidget.h
+ * @brief Declares the GraphicsWidget class for handling the main visualization widget in the network graph interface.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
 
 #ifndef GRAPHICSWIDGET_H
 #define GRAPHICSWIDGET_H
 
 
 #include <QGraphicsView>
-//#include <QMetaType>
+#include <QHash>
 
 class MainWindow;
-
 class GraphicsNode;
 class GraphicsEdge;
 class GraphicsNodeNumber;
@@ -45,7 +33,6 @@ class GraphicsEdgeLabel;
 typedef QHash<QString, GraphicsEdge*> H_StrToEdge;
 typedef QHash <int, GraphicsNode*> H_NumToNode;
 
-using namespace std;
 
 typedef QPair<int, int> SelectedEdge;
 
@@ -57,7 +44,7 @@ class GraphicsWidget : public QGraphicsView {
 
 public:
 
-    GraphicsWidget(QGraphicsScene *m_scene, MainWindow *m_parent);
+     GraphicsWidget(QGraphicsScene *m_scene, MainWindow *m_parent);
     ~GraphicsWidget();
 
     void clear();
@@ -68,10 +55,11 @@ public:
 
     void setInitNodeSize(int);
 
-    void setInitZoomIndex (int);
+    void setInitZoomIndex (const int &);
+    void setMaxZoomIndex (const int &);
 
     GraphicsNode* hasNode(QString text);
-    void setNodesMarked(QList<int> list);
+    void setSelectedNodes(QList<int> list);
 
     QList<QGraphicsItem *> selectedItems();
     QList<int> selectedNodes();
@@ -100,11 +88,10 @@ protected:
     void mousePressEvent ( QMouseEvent * e );
     void mouseReleaseEvent(QMouseEvent * e );
     void resizeEvent( QResizeEvent *e );
-    void paintEvent ( QPaintEvent * event );
 
 public slots:
 
-    void getSelectedItems();
+    void handleSelectionChanged();
 
     void relationSet(int relation);
 
@@ -121,26 +108,26 @@ public slots:
                   const QString &labelColor,
                   const int &labelSize,
                   const int &labelDistance);
-    void removeNode(const int &number);
-    void setNodeVisibility(int, bool );	//Called from Graph via MW
+    void removeNode(const int &nodeNum);
+    void setNodeVisibility(const int &nodeNum, const bool &toggle );	//Called from Graph via MW
     void setNodeClicked(GraphicsNode *);
     void moveNode(const int &num, const qreal &x, const qreal &y);
 
     bool setNodeSize(const int &nodeNumber, const int &size=0);
     void setNodeSizeAll(const int &size=0);
 
-    bool setNodeShape(const int &nodeNumber,
+    bool setNodeShape(const int &nodeNum,
                       const QString &shape,
                       const QString &iconPath=QString());
-    bool setNodeColor(const int &, const QString &color);
+    bool setNodeColor(const int &nodeNum, const QString &color);
 
-    void setNodeNumberColor(const int &nodeNumber, const QString &color);
+    void setNodeNumberColor(const int &nodeNum, const QString &color);
     void setNodeNumberVisibility(const bool &toggle);
-    bool setNodeNumberSize(const int &, const int &size=0);
+    bool setNodeNumberSize(const int &nodeNum, const int &size=0);
     bool setNodeNumberDistance(const int &, const int &distance=0);
 
     void setNodeLabelsVisibility(const bool &toggle);
-    bool setNodeLabelColor(const int &number, const QString &color="green");
+    bool setNodeLabelColor(const int &nodeNum, const QString &color="green");
     bool setNodeLabelSize(const int &, const int &size=0);
     bool setNodeLabel(const int & , const QString &label);
     bool setNodeLabelDistance(const int &, const int &distance=0);
@@ -159,15 +146,21 @@ public slots:
                     const int &target,
                     const bool &removeOpposite=false);
 
-    void setEdgeVisibility (int relation, int, int, bool);
+    void setEdgeVisibility (const int &relation,
+                            const int &sourceNum,
+                            const int &targetNum,
+                            const bool &visible,
+                            const bool &preserveReverseEdge=false,
+                            const int &edgeWeight=1,
+                            const int &reverseEdgeWeight=1);
 
-    bool setEdgeDirectionType(const int &,
-                              const int &,
+    bool setEdgeDirectionType(const int &source,
+                              const int &target,
                               const int &dirType=false);
 
     bool setEdgeWeight(const int &, const int &, const qreal &);
 
-    void setEdgeLabel(const int &, const int&, const QString &);
+    void setEdgeLabel(const int &source, const int &target, const QString &label);
 
     void setEdgeColor(const int &, const int&, const QString &);
 
@@ -182,23 +175,27 @@ public slots:
 
     void setEdgeHighlighting(const bool &toggle);
 
-    void startEdge(GraphicsNode *node);
+    void handleDoubleClickOnNode(GraphicsNode *node);
 
     void clearGuides();
     void addGuideCircle( const double&x0, const double&y0, const double&radius);
     void addGuideHLine(const double &y0);
 
-    void zoomIn(int level = 1);
-    void zoomOut(int level = 1);
+    void zoomIn(const int step = 1);
+    void zoomOut(const int step = 1);
     void rotateLeft();
     void rotateRight();
     void changeMatrixScale(const int value);
     void changeMatrixRotation(int angle);
     void reset();
 
+    void setOptionsOpenGL(const bool &enabled=false);
+    void setOptionsAntialiasing(const bool &toggle);
+    void setOptionsNoAntialiasingAutoAdjust(const bool &toggle);
+
 signals:
     void userDoubleClickNewNode(const QPointF &);
-    void userMiddleClicked(const int &, const int &);
+    void userMiddleClicked(const int &sourceNum, const int &targetNum, const qreal &weight=1);
     void userClickOnEmptySpace(const QPointF &p);
     void openNodeMenu();
     void openContextMenu(const QPointF p);
@@ -206,7 +203,7 @@ signals:
     //void userSelectedItems(const int nodes, const int edges);
     void userSelectedItems(const QList<int> selectedNodes,
                            const QList<SelectedEdge> selectedEdges);
-    void userClickedNode(const int &nodeNumber);
+    void userClickedNode(const int &nodeNumber, const QPointF &p);
     void userClickedEdge(const int &source, const int &target, const bool &openMenu=false);
     void zoomChanged(const int);
     void rotationChanged(const int);
@@ -216,23 +213,24 @@ signals:
 
 private:
 
-    H_NumToNode nodeHash;	//This is used in drawEdge() method
-    H_StrToEdge edgesHash; // helper hash to easily find edges
+    H_NumToNode nodeHash;	//Our basic hash table for node items
+    H_StrToEdge edgesHash; // Our basic hash table for edge items
     QList<int> m_selectedNodes;
     QList<SelectedEdge> m_selectedEdges;
     int m_curRelation, m_nodeSize;
     int m_currentRotationAngle;
-    int m_zoomIndex, markedEdgeSourceOrigSize, markedEdgeTargetOrigSize;
+    int m_zoomIndex, m_zoomIndexInit, m_zoomIndexMax;
+    int markedEdgeSourceOrigSize, markedEdgeTargetOrigSize;
     int m_edgeMinOffsetFromNode;
     double m_currentScaleFactor;
     qreal fX,fY, factor;
     QString m_nodeLabel, m_numberColor, m_labelColor;
     QString edgeName;
-    bool transformationActive;
-    bool secondDoubleClick, clickedEdgeExists;
+    bool m_isTransformationActive;
+    bool hasDoubleClickedNode, clickedEdgeExists;
     bool m_nodeNumbersInside, m_nodeNumberVisibility, m_nodeLabelVisibility;
     bool m_edgeHighlighting;
-    GraphicsNode *firstNode, *secondNode;
+    GraphicsNode *firstDoubleClickedNode, *secondDoubleClickedNode;
     GraphicsNode *markedEdgeSource;
     GraphicsNode *markedEdgeTarget;
     GraphicsEdge *clickedEdge;
