@@ -1,29 +1,17 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
- 
-                         graphvertex.h  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
+/**
+ * @file graphvertex.h
+ * @brief Declares the GraphVertex class for representing and managing vertices in the network graph structure.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
 #ifndef GRAPHVERTEX_H
 #define GRAPHVERTEX_H
@@ -35,11 +23,12 @@
 #include <QMultiHash>
 #include <QList>
 #include <QPointF>
+#include <QPair>
+
 #include <map>
 
 using namespace std;
 
-class QPointF;
 class Graph;
 
 
@@ -48,7 +37,6 @@ typedef QList<int> L_int;
 typedef QHash<int,QString> H_IntToStr;
 typedef QHash <QString, int> H_StrToInt;
 
-
 typedef QPair <qreal, bool> pair_f_b;
 typedef QPair <int, pair_f_b > pair_i_fb;
 typedef QMultiHash < int, pair_i_fb > H_edges;
@@ -66,42 +54,109 @@ class GraphVertex : public QObject{
 public:
 
     GraphVertex(Graph* parentGraph,
-           const int &name,
-           const int &val,
-           const int &relation,
-           const int &size,
-           const QString &color,
-           const QString &numColor,
-           const int &numSize,
-           const QString &label,
-           const QString &labelColor,
-           const int &labelSize,
-           const QPointF &p,
-           const QString &shape,
-                const QString &iconPath);
+                const int &name,
+                const int &relation,
+                const int &size,
+                const QString &color,
+                const QString &numColor,
+                const int &numSize,
+                const QString &label,
+                const QString &labelColor,
+                const int &labelSize,
+                const QPointF &p,
+                const QString &shape,
+                const QString &iconPath,
+                const int &edgesEstimate = 2000,
+                const QHash<QString,QString> &nodeAttr = QHash<QString,QString>()
+    );
 
     GraphVertex(const int &name);
 
     ~GraphVertex();
 
-    int name() const { return m_name; }
+    int number() const;
+    void setNumber(const int &number);
 
-    void setName (const int &name) { m_name=name; }
+    void setEnabled(const bool &status);
+    bool isEnabled () const;
 
-    void setEnabled (const bool &flag ) { m_enabled=flag; }
-    bool isEnabled () const { return m_enabled; }
+    void setSize(const int &size );
+    int size() const;
 
-    void relationSet(int newRel) ;
+    void setShape(const QString &shape, const QString &iconPath = QString());
+    QString shape() const;
+    QString shapeIconPath();
 
-    void edgeAddTo (const int &v2, const qreal &weight, const QString &color=QString(), const QString &label=QString());
-    void edgeAddFrom(const int &v1, const qreal &weight);
+    void setColor(const QString &color);
+    QString color() const;
+    QString colorToPajek();
 
-    void changeOutEdgeWeight (const int &target, const qreal &weight);
+    void setNumberColor (const QString &color);
+    QString numberColor() const;
 
-    void setOutEdgeEnabled (const int, bool);
+    void setNumberSize (const int &size);
+    int numberSize() const;
 
-    void edgeRemoveTo (const int target);
-    void edgeRemoveFrom(const int source);
+    void setNumberDistance (const int &distance);
+    int numberDistance() const;
+
+    void setLabel (const QString &label);
+    QString label() const;
+
+    void setLabelColor (const QString &labelColor);
+    QString labelColor() const;
+
+    void setLabelSize(const int &size);
+    int labelSize() const;
+
+    void setLabelDistance (const int &distance);
+    int labelDistance() const;
+
+    void setCustomAttributes(QHash<QString,QString> customAttributes);
+    QHash<QString,QString> customAttributes() const;
+
+    void setX(const qreal &x);
+    qreal x() const;
+
+    void setY(const qreal &y);
+    qreal y() const;
+
+    void setPos (QPointF &p);
+    QPointF pos () const;
+
+    void set_dispX (qreal x);
+    void set_dispY (qreal y);
+    QPointF & disp();
+
+    void setRelation(int newRel) ;
+
+    void addOutEdge (const int &v2, const qreal &weight, const QString &color=QString(), const QString &label=QString());
+    qreal hasEdgeTo(const int &v, const bool &allRelations=false);
+    void removeOutEdge (const int target);
+    void setOutEdgeWeight (const int &target, const qreal &weight);
+    void setOutEdgeEnabled (const int &target, bool);
+    void setOutLinkColor(const int &v2, const QString &color);
+    QString outLinkColor(const int &v2);
+    void setOutEdgeLabel(const int &v2, const QString &label);
+    QString outEdgeLabel(const int &v2) const;
+
+    void addInEdge(const int &v1, const qreal &weight);
+    qreal hasEdgeFrom (const int &v, const bool &allRelations=false);
+    void removeInEdge(const int source);
+    void setInEdgeWeight (const int &source, const qreal &weight);
+    void setInEdgeEnabled (const int &source, bool);
+
+    int outEdgesCount();
+    int outEdgesCountConst() const ;
+
+    int inEdgesCount();
+    int inEdgesCountConst() const ;
+
+    bool isOutLinked();
+    bool isInLinked();
+
+    void setIsolated(bool isolated);
+    bool isIsolated();
 
     QHash<int, qreal> outEdgesEnabledHash(const bool &allRelations=false);
     QHash<int,qreal>* outEdgesAllRelationsUniqueHash();
@@ -109,18 +164,15 @@ public:
     QHash<int,qreal> reciprocalEdgesHash();
     QList<int> neighborhoodList();
 
-    int outEdges();
-    int outEdgesConst() const ;
-
-    int inEdges();
-    int inEdgesConst() const ;
-
     int degreeOut();
     int outDegreeConst();
     int degreeIn();
     int inDegreeConst();
     int localDegree();
 
+    void setEnabledEdgesByRelation(const int relation, const bool status);
+    void setEnabledUnilateralEdges(const bool &status=false);
+
     qreal distance(const int &v1) ;
     void setDistance (const int &v1, const qreal &d) ;
     void reserveDistance(const int &N);
@@ -131,91 +183,11 @@ public:
     void reserveShortestPaths(const int &N);
     void clearShortestPaths();
 
+    void setEccentricity(const qreal &c);
+    qreal eccentricity();
 
-    /* sets eccentricity */
-    void setEccentricity (const qreal &c){ m_Eccentricity=c;}
-    qreal eccentricity() { return m_Eccentricity;}
-
-    /* Returns true if there is an outLink from this vertex */
-    bool isOutLinked() { return (outEdges() > 0) ? true:false;}
-    qreal hasEdgeTo(const int &v, const bool &allRelations=false);
-
-    /* Returns true if there is an outLink from this vertex */
-    bool isInLinked() { return  (inEdges() > 0) ? true:false;}
-    qreal hasEdgeFrom (const int &v, const bool &allRelations=false);
-
-    bool isIsolated() { return !(isOutLinked() | isInLinked()) ; }
-    void setIsolated(bool isolated) {m_isolated = isolated; }
-
-    void edgeFilterByWeight(qreal m_threshold, bool overThreshold);
-    //	void filterEdgesByColor(qreal m_threshold, bool overThreshold);
-    void edgeFilterByRelation(int relation, bool status);
-    void edgeFilterUnilateral(const bool &toggle=false);
-
-    void setSize(const int &size ) { m_size=size; }
-    int size()  const { return m_size; }
-
-    void setShape(const QString &shape, const QString &iconPath = QString()) { m_shape=shape; m_iconPath=iconPath;}
-    QString shape() const { return m_shape; }
-    QString shapeIconPath() {return m_iconPath; }
-
-    void setColor(const QString &color) { m_color=color; }
-    QString color() const { return m_color; }
-    QString colorToPajek();
-
-    void setNumberColor (const QString &color) { m_numberColor = color; }
-    QString numberColor() const { return m_numberColor; }
-
-    void setNumberSize (const int &size) { m_numberSize=size; }
-    int numberSize() const { return m_numberSize; }
-
-    void setNumberDistance (const int &distance) { m_numberDistance=distance; }
-    int numberDistance() const { return m_numberDistance; }
-
-    void setLabel (const QString &label) { m_label=label; }
-    QString label() const { return m_label; }
-
-    void setLabelColor (const QString &labelColor) { m_labelColor=labelColor; }
-    QString labelColor() const { return m_labelColor; }
-
-    void setLabelSize(const int &size) { m_labelSize=size; }
-    int labelSize() const { return m_labelSize; }
-
-    void setLabelDistance (const int &distance) { m_labelDistance=distance; }
-    int labelDistance() const { return m_labelDistance; }
-
-    void setX(const qreal &x) { m_x=x; }
-    qreal x() const { return m_x; }
-
-    void setY(const qreal &y) { m_y=y; }
-    qreal y() const { return m_y; }
-
-    QPointF pos () const { return QPointF ( x(), y() ); }
-    void setPos (QPointF &p) { m_x=p.x(); m_y=p.y(); }
-
-    //returns displacement vector
-    QPointF & disp() { return m_disp; }
-
-    void set_dispX (qreal x) { m_disp.rx() = x ; }
-    void set_dispY (qreal y) { m_disp.ry() = y ; }
-
-
-    void setOutLinkColor(const int &v2,
-                         const QString &color) { m_outLinkColors[v2]=color; }
-    QString outLinkColor(const int &v2) {
-        return ( m_outLinkColors.contains(v2) ) ? m_outLinkColors.value(v2) : "black";
-    }
-
-
-    void setOutEdgeLabel(const int &v2,
-                         const QString &label) { m_outEdgeLabels[v2]=label; }
-    QString outEdgeLabel(const int &v2) const {
-        return ( m_outEdgeLabels.contains(v2) ) ? m_outEdgeLabels.value(v2) : QString();
-    }
-
-
-    void setDelta (const qreal &c){ m_delta=c;} 		/* Sets vertex pair dependancy */
-    qreal delta() { return m_delta;}		/* Returns vertex pair dependancy */
+    void setDelta(const qreal &c);
+    qreal delta();
 
     void clearPs()	;
 
@@ -316,15 +288,22 @@ public:
     H_shortestPaths m_shortestPaths;
 
 signals:
-    void setEdgeVisibility (int, int, int, bool);
+    void signalSetEdgeVisibility (const int &relation,
+                                  const int &name,
+                                  const int &target,
+                                  const bool &visible,
+                                  const bool &preserveReverseEdge=false,
+                                  const int &edgeWeight=1,
+                                  const int &reverseEdgeWeight=1
+                                  );
 
 protected:
 
 private:
     Graph *m_graph;
-    int m_name,  m_outEdgesCounter, m_inEdgesCounter, m_outDegree, m_inDegree, m_localDegree;
+    int m_number,  m_outEdgesCounter, m_inEdgesCounter, m_outDegree, m_inDegree, m_localDegree;
     int m_outEdgesNonSym, m_inEdgesNonSym, m_outEdgesSym;
-    int m_value, m_size, m_labelSize, m_numberSize, m_numberDistance, m_labelDistance;
+    int m_size, m_labelSize, m_numberSize, m_numberDistance, m_labelDistance;
     int m_curRelation;
     bool m_reciprocalLinked, m_enabled, m_hasCLC, m_isolated;
     double m_x, m_y;
@@ -338,7 +317,8 @@ private:
     QString m_color, m_numberColor, m_label, m_labelColor, m_shape, m_iconPath;
     QPointF m_disp;
 
-    QMultiHash<int,qreal> m_reciprocalEdges;
+    QHash<QString,QString> m_customAttributes;
+    QHash<int,qreal> m_reciprocalEdges;
     L_int myPs;
     QMultiHash <int, L_int> m_cliques;
     L_int m_neighborhoodList;
