@@ -1,35 +1,22 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer
- version: 2.8
- Written in Qt
- 
-                         mainwindow.h  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    blog              : http://dimitris.apeiro.gr
-    project site      : https://socnetv.org
+/**
+ * @file mainwindow.h
+ * @brief Declares the MainWindow class, the primary interface for the SocNetV application.
+ * @author Dimitris B. Kalamaras (http://dimitris.apeiro.gr)
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-*******************************************************************************/
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-
 /** \file mainwindow.h
 
  \brief Documentation for the mainwindow file.
@@ -41,28 +28,13 @@
 #include <QMessageBox>
 #include <QStack>
 #include <QThread>
-//#include <QMetaType>
+#include <QNetworkReply>
 
+// Allows to use QT_CHARTS namespace directives (see below)
+#include <QtCharts/QChartGlobal>
 
 #include "global.h"
 
-#include "graph.h"    // needed here for static vars declared in Graph
-
-#include "forms/dialogfilteredgesbyweight.h"
-#include "forms/dialogdatasetselect.h"
-
-static const QString VERSION="2.8";
-
-static const int USER_MSG_INFO=0;
-static const int USER_MSG_CRITICAL=1;
-static const int USER_MSG_CRITICAL_NO_NETWORK=2;
-static const int USER_MSG_CRITICAL_NO_EDGES=3;
-static const int USER_MSG_QUESTION=4;
-static const int USER_MSG_QUESTION_CUSTOM=5;
-
-
-typedef QHash <QString, int> H_StrToInt;
-
 QT_BEGIN_NAMESPACE
 class QGraphicsScene;
 class QMenu;
@@ -77,51 +49,46 @@ class QComboBox;
 class QGroupBox;
 class QTabWidget;
 class QSpinBox;
-class QNetworkReply;
-class QDateTime;
 class QNetworkAccessManager;
+class QSslError;
+class QString;
+class QAbstractSeries;
+class QAbstractAxis;
+class QTextCodec;
 QT_END_NAMESPACE
 
 using namespace std;
 
 SOCNETV_USE_NAMESPACE
-
+class Graph;
 class GraphicsWidget;
-
 class GraphicsEdge;
 class GraphicsNode;
-
 class Chart;
-
-class DialogNodeFind;
-class DialogNodeEdit;
-
-class DialogEdgeDichotomization;
-
 class DialogPreviewFile;
-
+class DialogWebCrawler;
+class DialogDataSetSelect;
 class DialogRandErdosRenyi;
 class DialogRandSmallWorld;
 class DialogRandScaleFree;
 class DialogRandRegular;
 class DialogRandLattice;
-
 class DialogSimilarityPearson;
 class DialogSimilarityMatches;
 class DialogDissimilarities;
 class DialogClusteringHierarchical;
-
-class DialogWebCrawler;
-
 class DialogExportPDF;
 class DialogExportImage;
-
+class DialogNodeFind;
+class DialogNodeEdit;
+class DialogFilterNodesByCentrality;
+class DialogFilterEdgesByWeight;
+class DialogEdgeDichotomization;
 class DialogSettings;
-
 class DialogSystemInfo;
-
 class TextEditor;
 
+typedef QHash <QString, int> H_StrToInt;
 
 
 /**
@@ -140,10 +107,10 @@ class MainWindow : public QMainWindow
 
 public:
 
-    MainWindow(const QString &f);
+    MainWindow(const QString &m_fileName=QString(), const bool &forceProgress=false, const bool &maximized=false, const bool &fullscreen=false, const int &debugLevel=0);
     ~MainWindow();
 
-    void slotStyleSheetDefault(const bool checked);
+    void slotOptionsCustomStylesheet(const bool checked);
     void slotStyleSheetByName(const QString &sheetFileName);
 
     void polishProgressDialog(QProgressDialog* dialog);
@@ -157,7 +124,8 @@ public:
     void initPanels();
     void initWindowLayout();
     void initSignalSlots();
-    QMap<QString, QString> initSettings();
+    QMap<QString, QString> initSettings(const int &debugLevel=0, const bool &forceProgress=false);
+    void initNetworkAvailableTextCodecs();
     void saveSettings();
 
     void initApp();
@@ -175,20 +143,21 @@ public slots:
     //NETWORK MENU
     void slotNetworkNew();
     void slotNetworkFileChoose(QString m_fileName = QString(),
-                               int m_fileFormat = -1,
+                               int fileFormat = -1,
                                const bool &checkSelectFileType = true);
     void slotNetworkFileDialogFileSelected(const QString &fileName);
     void slotNetworkFileDialogFilterSelected(const QString &filter);
     void slotNetworkFileDialogRejected();
     void slotNetworkFileRecentUpdateActions();
-    void slotNetworkAvailableTextCodecs();
     bool slotNetworkFilePreview(const QString &, const int &);
-    void slotNetworkFileLoad ( const QString, const QString, const int );
+    void slotNetworkFileLoad (const QString &fileNameToLoad, const QString &codeName, const int &fileFormat);
     void slotNetworkFileLoaded(const int &type,
                                const QString &fName=QString(),
                                const QString &netName=QString(),
                                const int &totalNodes=0,
                                const int &totalEdges=0,
+                               const qreal &density=0,
+                               const qint64 &elapsedTime=0,
                                const QString &message=QString());
     void slotNetworkFileLoadRecent();
     void slotNetworkSavedStatus(const int &status);
@@ -204,16 +173,15 @@ public slots:
 
     void slotNetworkChanged(const bool &directed,
                             const int &vertices, const int &edges,
-                            const qreal &density);
+                            const qreal &density,
+                            const bool &needsSaving=true);
     void slotNetworkSave(const int &fileFormat=-1);
     void slotNetworkSaveAs();
-    void slotNetworkClose();
+    bool slotNetworkClose();
     void slotNetworkPrint();
     void slotNetworkViewSociomatrix();
     void slotNetworkViewSociomatrixPlotText();
 
-    bool slotNetworkExportPNG();
-
     void slotNetworkExportImageDialog();
     void slotNetworkExportImage ( const QString &filename,
                                   const QByteArray &format,
@@ -238,11 +206,11 @@ public slots:
 
     void slotNetworkRandomErdosRenyiDialog();
     void slotNetworkRandomErdosRenyi( const int N,
-                               const QString model,
-                               const int edges,
-                               const qreal eprob,
-                               const QString mode,
-                               const bool diag) ;
+                                      const QString model,
+                                      const int edges,
+                                      const qreal eprob,
+                                      const QString mode,
+                                      const bool diag) ;
     void slotNetworkRandomRegularDialog();
     void slotNetworkRandomRegular(const int &newNodes, const int &degree,
                                   const QString &mode, const bool &diag);
@@ -278,7 +246,7 @@ public slots:
 
     void slotNetworkWebCrawlerDialog();
 
-    void slotNetworkWebCrawler(const QString &urlSeed,
+    void slotNetworkWebCrawler(const QUrl &startUrl,
                                const QStringList &urlPatternsIncluded,
                                const QStringList &urlPatternsExcluded,
                                const QStringList &linkClasses,
@@ -288,39 +256,41 @@ public slots:
                                const bool &childLinks,
                                const bool &parentLinks,
                                const bool &selfLinks,
-                               const bool &extLinksIncluded,
+                               const bool &extLinks,
                                const bool &extLinksCrawl,
                                const bool &socialLinks,
                                const bool &delayedRequests);
 
+    void slotNetworkManagerRequest(const QUrl &url, const NetworkRequestType &requestType);
+
+
     //EDIT MENU
     void slotEditDragModeSelection(bool);
     void slotEditDragModeScroll(bool);
 
     void slotEditRelationsClear();
-    void slotEditRelationAdd(QString newRelationName=QString(),
-                             const bool &changeRelation=true);
-    void slotEditRelationChange(const int relIndex=RAND_MAX);
-    void slotEditRelationRename(QString newName=QString());
+
+    void slotEditRelationAddPrompt();
+
+    void slotEditRelationAdd(const QString &newRelationName);
+    void slotEditRelationChange(const int &relIndex=RAND_MAX);
+    void slotEditRelationRename();
 
     void slotEditOpenContextMenu(const QPointF & mPos);
     void slotEditSelectionChanged (const int &selNodes, const int &selEdges);
 
-    void slotEditClickOnEmptySpace (const QPointF &p);
-
     void slotEditNodeSelectAll();
     void slotEditNodeSelectNone();
     void slotEditNodeInfoStatusBar(const int &number,
                                    const QPointF &p,
                                    const QString &label,
                                    const int &inDegree,
-                                   const int &outDegree,
-                                   const qreal &clc=0);
+                                   const int &outDegree);
     void slotEditNodePosition(const int &nodeNumber, const int &x, const int &y);
     void slotEditNodeAdd();
 
     void slotEditNodeFindDialog();
-    void slotEditNodeFind(const QStringList &list,
+    void slotEditNodeFind(const QStringList &nodeList,
                           const QString &searchType,
                           const QString &indexStr=QString());
     void slotEditNodeRemove();
@@ -328,10 +298,10 @@ public slots:
     void slotEditNodePropertiesDialog();
     void slotEditNodeProperties( const QString &label,
                                  const int &size,
-                                 const QString &value,
                                  const QColor &color,
                                  const QString &shape,
-                                 const QString &iconPath
+                                 const QString &iconPath,
+                                 const QHash<QString, QString> &customAttributes
                                  );
     void slotEditNodeSelectedToClique();
     void slotEditNodeSelectedToStar();
@@ -350,7 +320,7 @@ public slots:
     void slotEditNodeLabelDistance(int v1=0, int newSize=0);
 
     void slotEditEdgeClicked (const MyEdge &edge=MyEdge(),
-                                    const bool &openMenu=false);
+                              const bool &openMenu=false);
 
     void slotEditEdgeOpenContextMenu(const QString &str="") ;
     void slotEditEdgeAdd();
@@ -371,7 +341,7 @@ public slots:
     void slotEditEdgeDichotomizationDialog();
     void slotEditEdgeDichotomization(const qreal threshold);
 
-    void slotFilterNodes();
+    void slotFilterNodesDialogByCentrality();
     void slotEditFilterNodesIsolates(bool checked);
     void slotEditFilterEdgesByWeightDialog();
     void slotEditFilterEdgesUnilateral(bool checked);
@@ -405,7 +375,7 @@ public slots:
     void slotLayoutGuides(const bool &toggle);
 
     //ANALYSIS MENU
-    void askAboutWeights(const bool userTriggered=false);
+    void askAboutEdgeWeights(const bool userTriggered=false);
 
     void slotAnalyzeReciprocity();
     void slotAnalyzeSymmetryCheck();
@@ -449,7 +419,7 @@ public slots:
                                                       QAbstractAxis *axisY=Q_NULLPTR,
                                                       const qreal &minF=0,
                                                       const qreal &maxF=0
-                                                       );
+            );
 
     void slotAnalyzeCommunitiesCliqueCensus();
     void slotAnalyzeCommunitiesTriadCensus();
@@ -464,19 +434,19 @@ public slots:
 
     void slotAnalyzeStrEquivalenceDissimilaritiesDialog();
     void slotAnalyzeStrEquivalenceDissimilaritiesTieProfile(const QString &metric,
-                                               const QString &varLocation,
-                                               const bool &diagonal);
+                                                            const QString &varLocation,
+                                                            const bool &diagonal);
 
     void slotAnalyzeStrEquivalenceSimilarityMeasureDialog();
     void slotAnalyzeStrEquivalenceSimilarityByMeasure(const QString &matrix,
-                               const QString &varLocation,
-                               const QString &measure,
-                               const bool &diagonal);
+                                                      const QString &varLocation,
+                                                      const QString &measure,
+                                                      const bool &diagonal);
 
     void slotAnalyzeStrEquivalencePearsonDialog();
     void slotAnalyzeStrEquivalencePearson(const QString &matrix,
-                               const QString &varLocation,
-                               const bool &diagonal=false);
+                                          const QString &varLocation,
+                                          const bool &diagonal=false);
 
 
 
@@ -496,6 +466,8 @@ public slots:
     void slotOptionsEdgesBezier(bool toggle);
     void slotOptionsEdgeArrowsVisibility(bool toggle);
 
+    void slotOptionsSaveZeroWeightEdges(bool toggle);
+
     void slotOptionsEmbedLogoExporting(bool toggle);
     void slotOptionsProgressDialogVisibility(bool toggle);
 
@@ -511,6 +483,7 @@ public slots:
     void slotOptionsBackgroundImageSelect(bool toggle);
     void slotOptionsBackgroundImage();
 
+    void slotOptionsCanvasOpenGL(const bool &toggle=false);
     void slotOptionsCanvasAntialiasing(bool toggle);
     void slotOptionsCanvasAntialiasingAutoAdjust(const bool &toggle=false);
     void slotOptionsCanvasSmoothPixmapTransform(const bool &toggle=false);
@@ -526,7 +499,7 @@ public slots:
     void slotHelpTips();
     void slotHelp();
     void slotHelpCheckUpdateDialog();
-    void slotHelpCheckUpdateParse(QNetworkReply *reply);
+    void slotHelpCheckUpdateParse();
     void slotHelpCreateTips();
     void slotHelpSystemInfo();
     void slotHelpAbout();
@@ -541,9 +514,11 @@ public slots:
                               QMessageBox::StandardButton defBtn=QMessageBox::Ok,
                               const QString btn1=QString(),
                               const QString btn2=QString()
-                               );
+            );
 
 
+    void slotNetworkManagerSslErrors(QNetworkReply *reply, const QList<QSslError> &errors);
+    void slotNetworkManagerReplyError(const QNetworkReply::NetworkError &code);
 
     //Called by Graph to display some message to the user
     void statusMessage(const QString);
@@ -566,64 +541,72 @@ public slots:
     void slotProgressBoxDestroy(const int &max=0);
 
 protected:
-    void resizeEvent( QResizeEvent * );
+    void resizeEvent(QResizeEvent * e);
     void closeEvent( QCloseEvent* ce );
-
-
-    //	void myMessageOutput(QtMsgType type, const char *msg);
 signals:
     void signalRelationAddAndChange(const QString &relName, const bool &changeRelation=true);
     void signalSetReportsDataDir(const QString &dataDir );
 
 private:
 
-    QGraphicsScene *scene;
-    GraphicsWidget *graphicsWidget;
+    enum { MaxRecentFiles = 5 };
 
-    Graph *activeGraph;
-
-    QMap<QString,QString> appSettings;
-
-    Chart *miniChart;
+    int progressCounter;
+    int fileType;
+    int nodesEstimatedSize;
+    int edgesPerNodeEstimatedSize;
+    int maxRandomlyCreatedNodes;
+    int fortuneCookiesCounter;
+    int initZoomIndex, maxZoomIndex;
+    bool inverseWeights, askedAboutWeights;
 
+    QString fileName, previous_fileName, fileNameNoPath, progressMsg;
+    QString initTextCodecName, userSelectedCodecName;
+    QString settingsFilePath, settingsDir ;
+    QStringList fortuneCookie;
+    QStringList tempFileNameNoPath, tips;
     QStringList prominenceIndexList;
     QStringList recentFiles;
     QStringList iconPathList;
     QStringList nodeShapeList;
 
+    QMap<QString,QString> appSettings;
+
+    QList<QTextCodec *> codecs;
+
+    QList<TextEditor *> m_textEditors;
+
+    QStack<QProgressDialog *> progressDialogs;
+
+    QPrinter *printer, *printerPDF;
+
+    QNetworkAccessManager *networkManager;
+    QGraphicsScene *scene;
+    GraphicsWidget *graphicsWidget;
+    Graph *activeGraph;
+    Chart *miniChart;
+
     DialogWebCrawler *m_WebCrawlerDialog;
     DialogDataSetSelect *m_datasetSelectDialog;
-
     DialogExportPDF *m_dialogExportPDF;
     DialogExportImage *m_dialogExportImage;
-
     DialogNodeEdit *m_nodeEditDialog;
     DialogNodeFind *m_nodeFindDialog;
-
+    DialogFilterNodesByCentrality *m_DialogNodeFilterByCentrality;
     DialogEdgeDichotomization *m_edgeDichotomizationDialog;
     DialogFilterEdgesByWeight *m_DialogEdgeFilterByWeight;
-
     DialogRandErdosRenyi *m_randErdosRenyiDialog;
     DialogRandSmallWorld *m_randSmallWorldDialog;
     DialogRandScaleFree *m_randScaleFreeDialog;
     DialogRandRegular *m_randRegularDialog;
     DialogRandLattice *m_randLatticeDialog;
-
     DialogSimilarityPearson *m_dialogSimilarityPearson;
     DialogSimilarityMatches *m_dialogSimilarityMatches;
     DialogDissimilarities *m_dialogdissimilarities;
     DialogClusteringHierarchical *m_dialogClusteringHierarchical;
-
     DialogSettings *m_settingsDialog;
     DialogSystemInfo *m_systemInfoDialog;
-
     DialogPreviewFile *m_dialogPreviewFile;
-    QList<QTextCodec *> codecs;
-    QString userSelectedCodecName;
-
-    QList<TextEditor *> m_textEditors;
-
-    QPrinter *printer, *printerPDF;
 
     QToolBar *toolBar;
 
@@ -631,8 +614,6 @@ private:
 
     QComboBox *editRelationChangeCombo;
 
-    QStack<QProgressDialog *> progressDialogs;
-
     QMenu *importSubMenu, *exportSubMenu, *editMenu, *analysisMenu, *helpMenu;
     QMenu *optionsMenu, *colorOptionsMenu, *edgeOptionsMenu, *nodeOptionsMenu;
     QMenu *editNodeMenu, *editEdgeMenu, *centrlMenu,  *viewOptionsMenu, *layoutMenu;
@@ -644,7 +625,7 @@ private:
     QMenu *colorationMenu;
 
     QComboBox *toolBoxNetworkAutoCreateSelect, *toolBoxEditNodeSubgraphSelect,
-              *toolBoxEditEdgeModeSelect, *toolBoxEditEdgeTransformSelect;
+    *toolBoxEditEdgeModeSelect, *toolBoxEditEdgeTransformSelect;
     QComboBox *toolBoxAnalysisCohesionSelect, *toolBoxAnalysisStrEquivalenceSelect,
     *toolBoxAnalysisProminenceSelect, *toolBoxAnalysisCommunitiesSelect,
     *toolBoxAnalysisMatricesSelect;
@@ -660,7 +641,7 @@ private:
 
     QAction *networkNewAct, *networkOpenAct, *networkSaveAct, *networkSaveAsAct,
     *networkCloseAct, *networkPrintAct,*networkQuitAct;
-    QAction *networkExportImageAct, *networkExportPNGAct, *networkExportPajek,
+    QAction *networkExportImageAct, *networkExportPajek,
     *networkExportPDFAct, *networkExportDLAct, *networkExportGWAct, *networkExportSMAct,
     *networkExportListAct;
     QAction *networkImportPajekAct, *networkImportGMLAct, *networkImportAdjAct, *networkImportListAct,
@@ -677,7 +658,7 @@ private:
     QAction *networkRandomLatticeAct;
     QAction *networkWebCrawlerAct;
 
-    QAction *editDragModeScrollAct, *editDragModeSelectAct;
+    QAction *editMouseModeScrollAct, *editMouseModeInteractiveAct;
     QAction *editNodeSelectNoneAct, *editNodeSelectAllAct;
     QAction *editNodeSelectedToStarAct, *editNodeSelectedToCycleAct;
     QAction *editNodeSelectedToLineAct, *editNodeSelectedToCliqueAct;
@@ -687,14 +668,14 @@ private:
     QAction *editNodeNumbersSizeAct, *editNodeLabelsSizeAct;
     QAction *editNodeSizeAllAct, *editNodeShapeAll;
     QAction *editEdgeLabelAct, *editEdgeColorAct, *editEdgeWeightAct;
-    QAction *filterNodesAct, *editFilterNodesIsolatesAct, *editFilterEdgesByWeightAct;
+    QAction *filterNodesByCentralityAct, *editFilterNodesIsolatesAct, *editFilterEdgesByWeightAct;
     QAction *editFilterEdgesUnilateralAct;
     QAction *transformNodes2EdgesAct, *editEdgeSymmetrizeAllAct;
     QAction *editEdgeSymmetrizeStrongTiesAct, *editEdgeUndirectedAllAct;
     QAction *editEdgeDichotomizeAct;
     QAction *editNodeColorAll, *editEdgeColorAllAct,
-            *editNodeNumbersColorAct,*editNodeLabelsColorAct,
-            *editEdgesCocitationAct;
+    *editNodeNumbersColorAct,*editNodeLabelsColorAct,
+    *editEdgesCocitationAct;
 
     QAction *optionsNodeNumbersVisibilityAct, *optionsNodeLabelsVisibilityAct, *optionsNodeNumbersInsideAct;
     QAction *optionsEdgeThicknessPerWeightAct, *optionsEdgeWeightNumbersAct;
@@ -708,9 +689,6 @@ private:
     QAction *helpAboutApp, *helpAboutQt, *helpApp, *tipsApp;
     QAction *helpSystemInfoAct, *helpCheckUpdatesApp;
 
-
-
-
     QAction *netDensity, *analyzeGraphReciprocityAct, *analyzeGraphSymmetryAct;
     QAction *analyzeGraphDistanceAct, *averGraphDistanceAct;
     QAction *analyzeMatrixDistancesGeodesicAct, *analyzeMatrixGeodesicsAct;
@@ -724,8 +702,8 @@ private:
     QAction *analyzeStrEquivalenceClusteringHierarchicalAct, *analyzeStrEquivalencePearsonAct;
     QAction *analyzeStrEquivalenceMatchesAct;
     QAction *cDegreeAct, *cInDegreeAct, *cClosenessAct, *cInfluenceRangeClosenessAct,
-            *cBetweennessAct, *cInformationAct, *cEigenvectorAct, *cPageRankAct,
-            *cStressAct, *cPowerAct, *cEccentAct, *cProximityPrestigeAct;
+    *cBetweennessAct, *cInformationAct, *cEigenvectorAct, *cPageRankAct,
+    *cStressAct, *cPowerAct, *cEccentAct, *cProximityPrestigeAct;
     QAction *layoutRandomAct, *layoutRandomRadialAct, *layoutGuidesAct;
     QAction *layoutRadialProminence_DC_Act, *layoutRadialProminence_DP_Act,
     *layoutRadialProminence_CC_Act, *layoutRadialProminence_SC_Act, *layoutRadialProminence_EC_Act,
@@ -754,25 +732,8 @@ private:
 
     QAction *editRelationNextAct, *editRelationPreviousAct, *editRelationAddAct;
     QAction *editRelationRenameAct;
-    enum { MaxRecentFiles = 5 };
     QAction *recentFileActs[MaxRecentFiles];
 
-    QString fileName, previous_fileName, fileNameNoPath, progressMsg;
-    QString settingsFilePath, settingsDir ;
-    QStringList fortuneCookie;
-    QStringList tempFileNameNoPath, tips;
-
-    int statusBarDuration, progressCounter;
-    int fileType, maxNodes;
-    int fortuneCookiesCounter;
-    int windowMinWidth, windowMinHeight;
-
-    //QString VERSION;
-
-    bool inverseWeights, askedAboutWeights;
-    qreal randomErdosEdgeProb;
-    QString initFileCodec;
-
     QLabel *rightPanelNetworkTypeLCD ;
     QLabel *rightPanelEdgesLabel;
 
@@ -784,7 +745,6 @@ private:
     QLabel *rightPanelClickedNodeLCD;
     QLabel *rightPanelClickedNodeInDegreeLCD;
     QLabel *rightPanelClickedNodeOutDegreeLCD;
-    QLabel *rightPanelClickedNodeClucofLCD;
 
     QLabel *rightPanelSelectedNodesLCD;
     QLabel *rightPanelSelectedEdgesLCD;
@@ -798,11 +758,8 @@ private:
     QLabel *rightPanelClickedEdgeReciprocalWeightLabel;
     QLabel *rightPanelClickedEdgeReciprocalWeightLCD;
 
-    QDateTime actualDateTime, actualDate, actualTime;
-    QTime eTime;     //used  to time algorithms.
 
-    QNetworkAccessManager *http;
-    QNetworkReply *reply;
+
 
 };
 #endif 
