@@ -1,34 +1,21 @@
-/***************************************************************************
- SocNetV: Social Network Visualizer 
- version: 2.8
- Written in Qt
+/**
+ * @file matrix.cpp
+ * @brief Implements the Matrix class for handling adjacency and sociomatrix data structures in network analysis.
+ * @author Dimitris B. Kalamaras
+ * @copyright
+ *   Copyright (C) 2005-2025 by Dimitris B. Kalamaras.
+ *   This file is part of SocNetV (Social Network Visualizer).
+ * @license
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, version 3 or later.
+ *   For more details, see <http://www.gnu.org/licenses/>.
+ * @see https://socnetv.org
+ */
 
-                        matrix  -  description
-                             -------------------
-    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
-    project site      : https://socnetv.org
-
- ***************************************************************************/
-
-/*******************************************************************************
-*     This program is free software: you can redistribute it and/or modify     *
-*     it under the terms of the GNU General Public License as published by     *
-*     the Free Software Foundation, either version 3 of the License, or        *
-*     (at your option) any later version.                                      *
-*                                                                              *
-*     This program is distributed in the hope that it will be useful,          *
-*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*     GNU General Public License for more details.                             *
-*                                                                              *
-*     You should have received a copy of the GNU General Public License        *
-*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
-********************************************************************************/
 
 #include "matrix.h"
 
-
-
 #define TINY 1.0e-20
 
 #include <cstdlib>		//allows the use of RAND_MAX macro
@@ -309,7 +296,6 @@ void Matrix::deleteRowColumn(int erased){
         row[i].setSize(m_cols);
     }
     qDebug() << "Matrix:deleteRowColumn() - finished, new matrix:";
-    //printMatrixConsole(true); // @TODO comment out to release
 
 }
 
@@ -898,8 +884,8 @@ void Matrix::powerIteration (
 
 
         qDebug() << "Matrix::powerIteration() - end of iteration"
-                 << iter << endl
-                 << "x" << x  << endl
+                 << iter << "\n"
+                 << "x" << x  << "\n"
                  << "distance from previous x " << distance
                  << "sum" << xsum
                  << "xmax" << xmax
@@ -1186,7 +1172,7 @@ bool Matrix::ludcmp (Matrix &a, const int &n, int indx[], qreal &d) {
         }
 
 
-//           stream << endl << "at j " << j+1 << " matrix a = LU = " << a ;
+//           stream << "\n" << "at j " << j+1 << " matrix a = LU = " << a ;
     }  // Go back for the next column in the reduction.
 
 
@@ -1326,12 +1312,15 @@ bool Matrix::solve(qreal b[])
 
     *A = *this;
 
-
     int n=rows();
     qreal d;
 
 //    int indx[n];
     int *indx = new  (nothrow) int [ n ];
+    if (!indx) {
+        delete A;
+        return false;
+    }
     Q_CHECK_PTR(indx);
 
     qDebug () << "Matrix::solve() - solving A x  - size " << n;
@@ -1340,13 +1329,15 @@ bool Matrix::solve(qreal b[])
     }
     if ( ! ludcmp(*A,n,indx,d) )
     { //  Decompose the matrix just once.
-        qDebug () << "Matrix::solve() - matrix a singular - RETURN";
+        delete A;
+        delete[] indx;
+        qDebug() << "Matrix::solve() - matrix a singular - RETURN";
         return false ;
     }
 
-    qDebug () << "Matrix::solve() - call lubksb";
+//    qDebug () << "Matrix::solve() - call lubksb";
     lubksb(*A, n, indx, b);
-    qDebug () << "Matrix::solve() - finished!";
+//    qDebug () << "Matrix::solve() - finished!";
 
     return true;
 }
@@ -1384,7 +1375,7 @@ Matrix& Matrix::distancesMatrix(const int &metric,
 
         N = rows() ;
 
-        QVector<qreal> mean (N,0); // holds mean values
+        QList<qreal> mean (N,0); // holds mean values
 
         qDebug()<< "Matrix::distancesMatrix() - input matrix:";
         //this->printMatrixConsole();
@@ -1494,7 +1485,7 @@ Matrix& Matrix::distancesMatrix(const int &metric,
 
         N = rows() ;
 
-        QVector<qreal> mean (N,0); // holds mean values
+        QList<qreal> mean (N,0); // holds mean values
 
         qDebug()<< "Matrix::distancesMatrix() -"
                 <<"input matrix";
@@ -1605,7 +1596,7 @@ Matrix& Matrix::distancesMatrix(const int &metric,
 
         CM.zeroMatrix(M,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
+        QList<qreal> mean (N,0); // holds mean values
 
         //create augmented matrix (concatenated rows and columns) from input matrix
         for (int i = 0 ; i < N  ; i++ ) {
@@ -1768,7 +1759,7 @@ Matrix& Matrix::similarityMatrix(Matrix &AM,
 
         this->zeroMatrix(N,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
+        QList<qreal> mean (N,0); // holds mean values
 
         qDebug()<< "Matrix::similarityMatrix() -"
                 <<"input matrix";
@@ -1869,7 +1860,7 @@ Matrix& Matrix::similarityMatrix(Matrix &AM,
 
         this->zeroMatrix(N,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
+        QList<qreal> mean (N,0); // holds mean values
 
         qDebug()<< "Matrix::similarityMatrix() -"
                 <<"input matrix";
@@ -1972,7 +1963,7 @@ Matrix& Matrix::similarityMatrix(Matrix &AM,
         this->zeroMatrix(N,N);
         CM.zeroMatrix(M,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
+        QList<qreal> mean (N,0); // holds mean values
 
 
         //create augmented matrix (concatenated rows and columns) from input matrix
@@ -2118,8 +2109,8 @@ Matrix& Matrix::pearsonCorrelationCoefficients(Matrix &AM,
 
         this->zeroMatrix(N,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
-        QVector<qreal> sigma(N,0);
+        QList<qreal> mean (N,0); // holds mean values
+        QList<qreal> sigma(N,0);
         qDebug()<< "Matrix::pearsonCorrelationCoefficients() -"
                 <<"input matrix";
         //AM.printMatrixConsole(true);
@@ -2201,8 +2192,8 @@ Matrix& Matrix::pearsonCorrelationCoefficients(Matrix &AM,
 
         this->zeroMatrix(N,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
-        QVector<qreal> sigma(N,0);
+        QList<qreal> mean (N,0); // holds mean values
+        QList<qreal> sigma(N,0);
 
         qDebug()<< "Matrix::pearsonCorrelationCoefficients() -"
                 <<"input matrix";
@@ -2279,8 +2270,8 @@ Matrix& Matrix::pearsonCorrelationCoefficients(Matrix &AM,
 
         CM.zeroMatrix(M,N);
 
-        QVector<qreal> mean (N,0); // holds mean values
-        QVector<qreal> sigma(N,0);
+        QList<qreal> mean (N,0); // holds mean values
+        QList<qreal> sigma(N,0);
 
 
         //create augmented matrix (concatenated rows and columns) from input matrix
@@ -2382,7 +2373,9 @@ Matrix& Matrix::pearsonCorrelationCoefficients(Matrix &AM,
  * @return
  */
 QTextStream& operator <<  (QTextStream& os, Matrix& m){
-    qDebug() << "Matrix: << Matrix";
+
+    qDebug() << "Printing matrix m to provided output stream...";
+
     int actorNumber=1, fieldWidth = 13;
     qreal maxVal, minVal, maxAbsVal, element;
     bool hasRealNumbers=false;
@@ -2392,10 +2385,10 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
     maxAbsVal = ( fabs(minVal) > fabs(maxVal) ) ? fabs(minVal) : fabs(maxVal) ;
 
 
-    os << qSetFieldWidth(0) << endl ;
+    os << qSetFieldWidth(0) << Qt::endl ;
 
     os << "- Values:        "
-       << ( (hasRealNumbers) ? ("real numbers (printed decimals 3)") : ("integers only" ) ) << endl;
+       << ( (hasRealNumbers) ? ("real numbers (printed decimals 3)") : ("integers only" ) ) << Qt::endl;
 
     os << "- Max value:  ";
 
@@ -2404,7 +2397,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
     else
         os <<   maxVal;
 
-    os << qSetFieldWidth(0) << endl ;
+    os << qSetFieldWidth(0) << Qt::endl ;
 
     os << "- Min value:   ";
 
@@ -2414,9 +2407,9 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
         os << minVal;
 
 
-    os << qSetFieldWidth(0) << endl << endl;
+    os << qSetFieldWidth(0) << Qt::endl << Qt::endl;
 
-    os << qSetFieldWidth(7) << fixed << right << "v"<< qSetFieldWidth(3) << "" ;
+    os << qSetFieldWidth(7) << Qt::fixed << Qt::right << "v"<< qSetFieldWidth(3) << "" ;
 
     os <<  ( (hasRealNumbers) ? qSetRealNumberPrecision(3) : qSetRealNumberPrecision(0) ) ;
 
@@ -2444,12 +2437,12 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
         else
             os << qSetFieldWidth(fieldWidth) ;
 
-        os <<  fixed << actorNumber;
+        os << Qt::fixed << actorNumber;
     }
 
-    os << qSetFieldWidth(0) << endl;
+    os << qSetFieldWidth(0) << Qt::endl;
 
-    os << qSetFieldWidth(7)<< endl;
+    os << qSetFieldWidth(7)<< Qt::endl;
 
     // print rows
     for (int r = 0; r < m.rows(); ++r) {
@@ -2465,14 +2458,14 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
             os << qSetFieldWidth(7) ;
 
 
-        os <<  fixed << actorNumber
+        os << Qt::fixed << actorNumber
             << qSetFieldWidth(3) <<"" ;
 
         for (int c = 0; c < m.cols(); ++c) {
             element = m(r,c) ;
-            os << qSetFieldWidth(fieldWidth) << fixed << right;
+            os << qSetFieldWidth(fieldWidth) << Qt::fixed << Qt::right;
             if ( element == RAND_MAX)  // we print inf symbol instead of RAND_MAX (distances matrix).
-                os << fixed << right << qSetFieldWidth(fieldWidth) << infinity ;
+                os << Qt::fixed << Qt::right << qSetFieldWidth(fieldWidth) << infinity ;
             else {
                 if ( element > 999)
                     os << qSetFieldWidth(fieldWidth-3) ;
@@ -2485,7 +2478,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
                 os <<  element;
             }
         }
-        os << qSetFieldWidth(0) << endl;
+        os << qSetFieldWidth(0) << Qt::endl;
     }
     return os;
 }
@@ -2521,25 +2514,25 @@ bool Matrix::printHTMLTable(QTextStream& os,
         os << "<pre>";
 
         // print first/header row
-        os << "<span class=\"header\">" << qSetFieldWidth(5) << right << "A/A";
-        os <<  fixed << qSetFieldWidth(10) << right ;
+        os << "<span class=\"header\">" << qSetFieldWidth(5) << Qt::right << "A/A";
+        os << Qt::fixed << qSetFieldWidth(10) << Qt::right ;
         for (int r = 0; r < cols(); ++r) {
             elementLabel = r+1;
             os << elementLabel;
         }
-        os << qSetFieldWidth(0) << "</span>"<< endl;
+        os << qSetFieldWidth(0) << "</span>"<< Qt::endl;
 
         for (int r = 0; r < rows(); ++r) {
             elementLabel = r+1;
             rowCount++;
 
-            os << "<span class=\"header\">" << qSetFieldWidth(5) << right;
+            os << "<span class=\"header\">" << qSetFieldWidth(5) << Qt::right;
             os << elementLabel;
             os << qSetFieldWidth(0) << "</span>";
 
             for (int c = 0; c < cols(); ++c) {
                 element = item(r,c) ;
-                os << fixed << qSetFieldWidth(10) << right;
+                os << Qt::fixed << qSetFieldWidth(10) << Qt::right;
                 if (  element == RAND_MAX)  // print inf symbol instead of RAND_MAX (distances matrix).
                     os << infinity;
                 else {
@@ -2549,7 +2542,7 @@ bool Matrix::printHTMLTable(QTextStream& os,
                // os << "";
             }
 
-            os << qSetFieldWidth(0) << endl;
+            os << qSetFieldWidth(0) << Qt::endl;
         }
 
         os << "</pre>";
@@ -2589,7 +2582,7 @@ bool Matrix::printHTMLTable(QTextStream& os,
 
         for (int c = 0; c < cols(); ++c) {
             element = item(r,c) ;
-            os << fixed << right;
+            os << Qt::fixed << Qt::right;
             os <<"<td" << ((markDiag && r==c)? " class=\"diag\">" : ">");
             if ( ( element == RAND_MAX ) && printInfinity) {
                 // print inf symbol instead of RAND_MAX (distances matrix).
@@ -2606,7 +2599,7 @@ bool Matrix::printHTMLTable(QTextStream& os,
     os << "</tbody></table>";
 
 
-    os << qSetFieldWidth(0) << endl ;
+    os << qSetFieldWidth(0) << Qt::endl ;
 
 
     os << "<p>"
@@ -2649,19 +2642,19 @@ bool Matrix::printMatrixConsole(bool debug){
         for (int c = 0; c < cols(); ++c) {
             if ( item(r,c) < RAND_MAX  ) {
                 out <<  qSetFieldWidth(12) << qSetRealNumberPrecision(3)
-                     <<  forcepoint << fixed<<right
+                    << Qt::forcepoint << Qt::fixed << Qt::right
                         << item(r,c);
             }
             else {
                 out <<  qSetFieldWidth(12) << qSetRealNumberPrecision(3)
-                     <<  forcepoint << fixed<<right
+                    << Qt::forcepoint << Qt::fixed << Qt::right
                         << "x";
             }
 
 //            QTextStream( (debug ? stderr : stdout) )
 //                    << ( (item(r,c) < RAND_MAX ) ? item(r,c) : INFINITY  )<<' ';
         }
-        out <<qSetFieldWidth(0)<< endl;
+        out << qSetFieldWidth(0)<< Qt::endl;
     }
     return true;
 }
